;;; ucs-hangul.el --- UCS table of Hangul Syllables

;; Copyright (C) 1998 MORIOKA Tomohiko.

;; Author: MORIOKA Tomohiko <morioka@jaist.ac.jp>
;; Keywords: ISO/IEC 10646, Unicode, charset, MULE, Hangul Syllables

;; This file is part of XEmacs-UCS.

;; XEmacs-UCS is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published
;; by the Free Software Foundation; either version 2, or (at your
;; option) any later version.

;; XEmacs-UCS is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with XEmacs; see the file COPYING.  If not, write to the Free
;; Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
;; 02111-1307, USA.

;;; Code:

(require 'ucs-util)

(ucs-set-char #xAC00 ?가) ; KS0-C-3021
(ucs-set-char #xAC01 ?각) ; KS0-C-3022
(ucs-set-char #xAC04 ?간) ; KS0-C-3023
(ucs-set-char #xAC07 ?갇) ; KS0-C-3024
(ucs-set-char #xAC08 ?갈) ; KS0-C-3025
(ucs-set-char #xAC09 ?갉) ; KS0-C-3026
(ucs-set-char #xAC0A ?갊) ; KS0-C-3027
(ucs-set-char #xAC10 ?감) ; KS0-C-3028
(ucs-set-char #xAC11 ?갑) ; KS0-C-3029
(ucs-set-char #xAC12 ?값) ; KS0-C-302A
(ucs-set-char #xAC13 ?갓) ; KS0-C-302B
(ucs-set-char #xAC14 ?갔) ; KS0-C-302C
(ucs-set-char #xAC15 ?강) ; KS0-C-302D
(ucs-set-char #xAC16 ?갖) ; KS0-C-302E
(ucs-set-char #xAC17 ?갗) ; KS0-C-302F
(ucs-set-char #xAC19 ?같) ; KS0-C-3030
(ucs-set-char #xAC1A ?갚) ; KS0-C-3031
(ucs-set-char #xAC1B ?갛) ; KS0-C-3032
(ucs-set-char #xAC1C ?개) ; KS0-C-3033
(ucs-set-char #xAC1D ?객) ; KS0-C-3034
(ucs-set-char #xAC20 ?갠) ; KS0-C-3035
(ucs-set-char #xAC24 ?갤) ; KS0-C-3036
(ucs-set-char #xAC2C ?갬) ; KS0-C-3037
(ucs-set-char #xAC2D ?갭) ; KS0-C-3038
(ucs-set-char #xAC2F ?갯) ; KS0-C-3039
(ucs-set-char #xAC30 ?갰) ; KS0-C-303A
(ucs-set-char #xAC31 ?갱) ; KS0-C-303B
(ucs-set-char #xAC38 ?갸) ; KS0-C-303C
(ucs-set-char #xAC39 ?갹) ; KS0-C-303D
(ucs-set-char #xAC3C ?갼) ; KS0-C-303E
(ucs-set-char #xAC40 ?걀) ; KS0-C-303F
(ucs-set-char #xAC4B ?걋) ; KS0-C-3040
(ucs-set-char #xAC4D ?걍) ; KS0-C-3041
(ucs-set-char #xAC54 ?걔) ; KS0-C-3042
(ucs-set-char #xAC58 ?걘) ; KS0-C-3043
(ucs-set-char #xAC5C ?걜) ; KS0-C-3044
(ucs-set-char #xAC70 ?거) ; KS0-C-3045
(ucs-set-char #xAC71 ?걱) ; KS0-C-3046
(ucs-set-char #xAC74 ?건) ; KS0-C-3047
(ucs-set-char #xAC77 ?걷) ; KS0-C-3048
(ucs-set-char #xAC78 ?걸) ; KS0-C-3049
(ucs-set-char #xAC7A ?걺) ; KS0-C-304A
(ucs-set-char #xAC80 ?검) ; KS0-C-304B
(ucs-set-char #xAC81 ?겁) ; KS0-C-304C
(ucs-set-char #xAC83 ?것) ; KS0-C-304D
(ucs-set-char #xAC84 ?겄) ; KS0-C-304E
(ucs-set-char #xAC85 ?겅) ; KS0-C-304F
(ucs-set-char #xAC86 ?겆) ; KS0-C-3050
(ucs-set-char #xAC89 ?겉) ; KS0-C-3051
(ucs-set-char #xAC8A ?겊) ; KS0-C-3052
(ucs-set-char #xAC8B ?겋) ; KS0-C-3053
(ucs-set-char #xAC8C ?게) ; KS0-C-3054
(ucs-set-char #xAC90 ?겐) ; KS0-C-3055
(ucs-set-char #xAC94 ?겔) ; KS0-C-3056
(ucs-set-char #xAC9C ?겜) ; KS0-C-3057
(ucs-set-char #xAC9D ?겝) ; KS0-C-3058
(ucs-set-char #xAC9F ?겟) ; KS0-C-3059
(ucs-set-char #xACA0 ?겠) ; KS0-C-305A
(ucs-set-char #xACA1 ?겡) ; KS0-C-305B
(ucs-set-char #xACA8 ?겨) ; KS0-C-305C
(ucs-set-char #xACA9 ?격) ; KS0-C-305D
(ucs-set-char #xACAA ?겪) ; KS0-C-305E
(ucs-set-char #xACAC ?견) ; KS0-C-305F
(ucs-set-char #xACAF ?겯) ; KS0-C-3060
(ucs-set-char #xACB0 ?결) ; KS0-C-3061
(ucs-set-char #xACB8 ?겸) ; KS0-C-3062
(ucs-set-char #xACB9 ?겹) ; KS0-C-3063
(ucs-set-char #xACBB ?겻) ; KS0-C-3064
(ucs-set-char #xACBC ?겼) ; KS0-C-3065
(ucs-set-char #xACBD ?경) ; KS0-C-3066
(ucs-set-char #xACC1 ?곁) ; KS0-C-3067
(ucs-set-char #xACC4 ?계) ; KS0-C-3068
(ucs-set-char #xACC8 ?곈) ; KS0-C-3069
(ucs-set-char #xACCC ?곌) ; KS0-C-306A
(ucs-set-char #xACD5 ?곕) ; KS0-C-306B
(ucs-set-char #xACD7 ?곗) ; KS0-C-306C
(ucs-set-char #xACE0 ?고) ; KS0-C-306D
(ucs-set-char #xACE1 ?곡) ; KS0-C-306E
(ucs-set-char #xACE4 ?곤) ; KS0-C-306F
(ucs-set-char #xACE7 ?곧) ; KS0-C-3070
(ucs-set-char #xACE8 ?골) ; KS0-C-3071
(ucs-set-char #xACEA ?곪) ; KS0-C-3072
(ucs-set-char #xACEC ?곬) ; KS0-C-3073
(ucs-set-char #xACEF ?곯) ; KS0-C-3074
(ucs-set-char #xACF0 ?곰) ; KS0-C-3075
(ucs-set-char #xACF1 ?곱) ; KS0-C-3076
(ucs-set-char #xACF3 ?곳) ; KS0-C-3077
(ucs-set-char #xACF5 ?공) ; KS0-C-3078
(ucs-set-char #xACF6 ?곶) ; KS0-C-3079
(ucs-set-char #xACFC ?과) ; KS0-C-307A
(ucs-set-char #xACFD ?곽) ; KS0-C-307B
(ucs-set-char #xAD00 ?관) ; KS0-C-307C
(ucs-set-char #xAD04 ?괄) ; KS0-C-307D
(ucs-set-char #xAD06 ?괆) ; KS0-C-307E
(ucs-set-char #xAD0C ?괌) ; KS0-C-3121
(ucs-set-char #xAD0D ?괍) ; KS0-C-3122
(ucs-set-char #xAD0F ?괏) ; KS0-C-3123
(ucs-set-char #xAD11 ?광) ; KS0-C-3124
(ucs-set-char #xAD18 ?괘) ; KS0-C-3125
(ucs-set-char #xAD1C ?괜) ; KS0-C-3126
(ucs-set-char #xAD20 ?괠) ; KS0-C-3127
(ucs-set-char #xAD29 ?괩) ; KS0-C-3128
(ucs-set-char #xAD2C ?괬) ; KS0-C-3129
(ucs-set-char #xAD2D ?괭) ; KS0-C-312A
(ucs-set-char #xAD34 ?괴) ; KS0-C-312B
(ucs-set-char #xAD35 ?괵) ; KS0-C-312C
(ucs-set-char #xAD38 ?괸) ; KS0-C-312D
(ucs-set-char #xAD3C ?괼) ; KS0-C-312E
(ucs-set-char #xAD44 ?굄) ; KS0-C-312F
(ucs-set-char #xAD45 ?굅) ; KS0-C-3130
(ucs-set-char #xAD47 ?굇) ; KS0-C-3131
(ucs-set-char #xAD49 ?굉) ; KS0-C-3132
(ucs-set-char #xAD50 ?교) ; KS0-C-3133
(ucs-set-char #xAD54 ?굔) ; KS0-C-3134
(ucs-set-char #xAD58 ?굘) ; KS0-C-3135
(ucs-set-char #xAD61 ?굡) ; KS0-C-3136
(ucs-set-char #xAD63 ?굣) ; KS0-C-3137
(ucs-set-char #xAD6C ?구) ; KS0-C-3138
(ucs-set-char #xAD6D ?국) ; KS0-C-3139
(ucs-set-char #xAD70 ?군) ; KS0-C-313A
(ucs-set-char #xAD73 ?굳) ; KS0-C-313B
(ucs-set-char #xAD74 ?굴) ; KS0-C-313C
(ucs-set-char #xAD75 ?굵) ; KS0-C-313D
(ucs-set-char #xAD76 ?굶) ; KS0-C-313E
(ucs-set-char #xAD7B ?굻) ; KS0-C-313F
(ucs-set-char #xAD7C ?굼) ; KS0-C-3140
(ucs-set-char #xAD7D ?굽) ; KS0-C-3141
(ucs-set-char #xAD7F ?굿) ; KS0-C-3142
(ucs-set-char #xAD81 ?궁) ; KS0-C-3143
(ucs-set-char #xAD82 ?궂) ; KS0-C-3144
(ucs-set-char #xAD88 ?궈) ; KS0-C-3145
(ucs-set-char #xAD89 ?궉) ; KS0-C-3146
(ucs-set-char #xAD8C ?권) ; KS0-C-3147
(ucs-set-char #xAD90 ?궐) ; KS0-C-3148
(ucs-set-char #xAD9C ?궜) ; KS0-C-3149
(ucs-set-char #xAD9D ?궝) ; KS0-C-314A
(ucs-set-char #xADA4 ?궤) ; KS0-C-314B
(ucs-set-char #xADB7 ?궷) ; KS0-C-314C
(ucs-set-char #xADC0 ?귀) ; KS0-C-314D
(ucs-set-char #xADC1 ?귁) ; KS0-C-314E
(ucs-set-char #xADC4 ?귄) ; KS0-C-314F
(ucs-set-char #xADC8 ?귈) ; KS0-C-3150
(ucs-set-char #xADD0 ?귐) ; KS0-C-3151
(ucs-set-char #xADD1 ?귑) ; KS0-C-3152
(ucs-set-char #xADD3 ?귓) ; KS0-C-3153
(ucs-set-char #xADDC ?규) ; KS0-C-3154
(ucs-set-char #xADE0 ?균) ; KS0-C-3155
(ucs-set-char #xADE4 ?귤) ; KS0-C-3156
(ucs-set-char #xADF8 ?그) ; KS0-C-3157
(ucs-set-char #xADF9 ?극) ; KS0-C-3158
(ucs-set-char #xADFC ?근) ; KS0-C-3159
(ucs-set-char #xADFF ?귿) ; KS0-C-315A
(ucs-set-char #xAE00 ?글) ; KS0-C-315B
(ucs-set-char #xAE01 ?긁) ; KS0-C-315C
(ucs-set-char #xAE08 ?금) ; KS0-C-315D
(ucs-set-char #xAE09 ?급) ; KS0-C-315E
(ucs-set-char #xAE0B ?긋) ; KS0-C-315F
(ucs-set-char #xAE0D ?긍) ; KS0-C-3160
(ucs-set-char #xAE14 ?긔) ; KS0-C-3161
(ucs-set-char #xAE30 ?기) ; KS0-C-3162
(ucs-set-char #xAE31 ?긱) ; KS0-C-3163
(ucs-set-char #xAE34 ?긴) ; KS0-C-3164
(ucs-set-char #xAE37 ?긷) ; KS0-C-3165
(ucs-set-char #xAE38 ?길) ; KS0-C-3166
(ucs-set-char #xAE3A ?긺) ; KS0-C-3167
(ucs-set-char #xAE40 ?김) ; KS0-C-3168
(ucs-set-char #xAE41 ?깁) ; KS0-C-3169
(ucs-set-char #xAE43 ?깃) ; KS0-C-316A
(ucs-set-char #xAE45 ?깅) ; KS0-C-316B
(ucs-set-char #xAE46 ?깆) ; KS0-C-316C
(ucs-set-char #xAE4A ?깊) ; KS0-C-316D
(ucs-set-char #xAE4C ?까) ; KS0-C-316E
(ucs-set-char #xAE4D ?깍) ; KS0-C-316F
(ucs-set-char #xAE4E ?깎) ; KS0-C-3170
(ucs-set-char #xAE50 ?깐) ; KS0-C-3171
(ucs-set-char #xAE54 ?깔) ; KS0-C-3172
(ucs-set-char #xAE56 ?깖) ; KS0-C-3173
(ucs-set-char #xAE5C ?깜) ; KS0-C-3174
(ucs-set-char #xAE5D ?깝) ; KS0-C-3175
(ucs-set-char #xAE5F ?깟) ; KS0-C-3176
(ucs-set-char #xAE60 ?깠) ; KS0-C-3177
(ucs-set-char #xAE61 ?깡) ; KS0-C-3178
(ucs-set-char #xAE65 ?깥) ; KS0-C-3179
(ucs-set-char #xAE68 ?깨) ; KS0-C-317A
(ucs-set-char #xAE69 ?깩) ; KS0-C-317B
(ucs-set-char #xAE6C ?깬) ; KS0-C-317C
(ucs-set-char #xAE70 ?깰) ; KS0-C-317D
(ucs-set-char #xAE78 ?깸) ; KS0-C-317E
(ucs-set-char #xAE79 ?깹) ; KS0-C-3221
(ucs-set-char #xAE7B ?깻) ; KS0-C-3222
(ucs-set-char #xAE7C ?깼) ; KS0-C-3223
(ucs-set-char #xAE7D ?깽) ; KS0-C-3224
(ucs-set-char #xAE84 ?꺄) ; KS0-C-3225
(ucs-set-char #xAE85 ?꺅) ; KS0-C-3226
(ucs-set-char #xAE8C ?꺌) ; KS0-C-3227
(ucs-set-char #xAEBC ?꺼) ; KS0-C-3228
(ucs-set-char #xAEBD ?꺽) ; KS0-C-3229
(ucs-set-char #xAEBE ?꺾) ; KS0-C-322A
(ucs-set-char #xAEC0 ?껀) ; KS0-C-322B
(ucs-set-char #xAEC4 ?껄) ; KS0-C-322C
(ucs-set-char #xAECC ?껌) ; KS0-C-322D
(ucs-set-char #xAECD ?껍) ; KS0-C-322E
(ucs-set-char #xAECF ?껏) ; KS0-C-322F
(ucs-set-char #xAED0 ?껐) ; KS0-C-3230
(ucs-set-char #xAED1 ?껑) ; KS0-C-3231
(ucs-set-char #xAED8 ?께) ; KS0-C-3232
(ucs-set-char #xAED9 ?껙) ; KS0-C-3233
(ucs-set-char #xAEDC ?껜) ; KS0-C-3234
(ucs-set-char #xAEE8 ?껨) ; KS0-C-3235
(ucs-set-char #xAEEB ?껫) ; KS0-C-3236
(ucs-set-char #xAEED ?껭) ; KS0-C-3237
(ucs-set-char #xAEF4 ?껴) ; KS0-C-3238
(ucs-set-char #xAEF8 ?껸) ; KS0-C-3239
(ucs-set-char #xAEFC ?껼) ; KS0-C-323A
(ucs-set-char #xAF07 ?꼇) ; KS0-C-323B
(ucs-set-char #xAF08 ?꼈) ; KS0-C-323C
(ucs-set-char #xAF0D ?꼍) ; KS0-C-323D
(ucs-set-char #xAF10 ?꼐) ; KS0-C-323E
(ucs-set-char #xAF2C ?꼬) ; KS0-C-323F
(ucs-set-char #xAF2D ?꼭) ; KS0-C-3240
(ucs-set-char #xAF30 ?꼰) ; KS0-C-3241
(ucs-set-char #xAF32 ?꼲) ; KS0-C-3242
(ucs-set-char #xAF34 ?꼴) ; KS0-C-3243
(ucs-set-char #xAF3C ?꼼) ; KS0-C-3244
(ucs-set-char #xAF3D ?꼽) ; KS0-C-3245
(ucs-set-char #xAF3F ?꼿) ; KS0-C-3246
(ucs-set-char #xAF41 ?꽁) ; KS0-C-3247
(ucs-set-char #xAF42 ?꽂) ; KS0-C-3248
(ucs-set-char #xAF43 ?꽃) ; KS0-C-3249
(ucs-set-char #xAF48 ?꽈) ; KS0-C-324A
(ucs-set-char #xAF49 ?꽉) ; KS0-C-324B
(ucs-set-char #xAF50 ?꽐) ; KS0-C-324C
(ucs-set-char #xAF5C ?꽜) ; KS0-C-324D
(ucs-set-char #xAF5D ?꽝) ; KS0-C-324E
(ucs-set-char #xAF64 ?꽤) ; KS0-C-324F
(ucs-set-char #xAF65 ?꽥) ; KS0-C-3250
(ucs-set-char #xAF79 ?꽹) ; KS0-C-3251
(ucs-set-char #xAF80 ?꾀) ; KS0-C-3252
(ucs-set-char #xAF84 ?꾄) ; KS0-C-3253
(ucs-set-char #xAF88 ?꾈) ; KS0-C-3254
(ucs-set-char #xAF90 ?꾐) ; KS0-C-3255
(ucs-set-char #xAF91 ?꾑) ; KS0-C-3256
(ucs-set-char #xAF95 ?꾕) ; KS0-C-3257
(ucs-set-char #xAF9C ?꾜) ; KS0-C-3258
(ucs-set-char #xAFB8 ?꾸) ; KS0-C-3259
(ucs-set-char #xAFB9 ?꾹) ; KS0-C-325A
(ucs-set-char #xAFBC ?꾼) ; KS0-C-325B
(ucs-set-char #xAFC0 ?꿀) ; KS0-C-325C
(ucs-set-char #xAFC7 ?꿇) ; KS0-C-325D
(ucs-set-char #xAFC8 ?꿈) ; KS0-C-325E
(ucs-set-char #xAFC9 ?꿉) ; KS0-C-325F
(ucs-set-char #xAFCB ?꿋) ; KS0-C-3260
(ucs-set-char #xAFCD ?꿍) ; KS0-C-3261
(ucs-set-char #xAFCE ?꿎) ; KS0-C-3262
(ucs-set-char #xAFD4 ?꿔) ; KS0-C-3263
(ucs-set-char #xAFDC ?꿜) ; KS0-C-3264
(ucs-set-char #xAFE8 ?꿨) ; KS0-C-3265
(ucs-set-char #xAFE9 ?꿩) ; KS0-C-3266
(ucs-set-char #xAFF0 ?꿰) ; KS0-C-3267
(ucs-set-char #xAFF1 ?꿱) ; KS0-C-3268
(ucs-set-char #xAFF4 ?꿴) ; KS0-C-3269
(ucs-set-char #xAFF8 ?꿸) ; KS0-C-326A
(ucs-set-char #xB000 ?뀀) ; KS0-C-326B
(ucs-set-char #xB001 ?뀁) ; KS0-C-326C
(ucs-set-char #xB004 ?뀄) ; KS0-C-326D
(ucs-set-char #xB00C ?뀌) ; KS0-C-326E
(ucs-set-char #xB010 ?뀐) ; KS0-C-326F
(ucs-set-char #xB014 ?뀔) ; KS0-C-3270
(ucs-set-char #xB01C ?뀜) ; KS0-C-3271
(ucs-set-char #xB01D ?뀝) ; KS0-C-3272
(ucs-set-char #xB028 ?뀨) ; KS0-C-3273
(ucs-set-char #xB044 ?끄) ; KS0-C-3274
(ucs-set-char #xB045 ?끅) ; KS0-C-3275
(ucs-set-char #xB048 ?끈) ; KS0-C-3276
(ucs-set-char #xB04A ?끊) ; KS0-C-3277
(ucs-set-char #xB04C ?끌) ; KS0-C-3278
(ucs-set-char #xB04E ?끎) ; KS0-C-3279
(ucs-set-char #xB053 ?끓) ; KS0-C-327A
(ucs-set-char #xB054 ?끔) ; KS0-C-327B
(ucs-set-char #xB055 ?끕) ; KS0-C-327C
(ucs-set-char #xB057 ?끗) ; KS0-C-327D
(ucs-set-char #xB059 ?끙) ; KS0-C-327E
(ucs-set-char #xB05D ?끝) ; KS0-C-3321
(ucs-set-char #xB07C ?끼) ; KS0-C-3322
(ucs-set-char #xB07D ?끽) ; KS0-C-3323
(ucs-set-char #xB080 ?낀) ; KS0-C-3324
(ucs-set-char #xB084 ?낄) ; KS0-C-3325
(ucs-set-char #xB08C ?낌) ; KS0-C-3326
(ucs-set-char #xB08D ?낍) ; KS0-C-3327
(ucs-set-char #xB08F ?낏) ; KS0-C-3328
(ucs-set-char #xB091 ?낑) ; KS0-C-3329
(ucs-set-char #xB098 ?나) ; KS0-C-332A
(ucs-set-char #xB099 ?낙) ; KS0-C-332B
(ucs-set-char #xB09A ?낚) ; KS0-C-332C
(ucs-set-char #xB09C ?난) ; KS0-C-332D
(ucs-set-char #xB09F ?낟) ; KS0-C-332E
(ucs-set-char #xB0A0 ?날) ; KS0-C-332F
(ucs-set-char #xB0A1 ?낡) ; KS0-C-3330
(ucs-set-char #xB0A2 ?낢) ; KS0-C-3331
(ucs-set-char #xB0A8 ?남) ; KS0-C-3332
(ucs-set-char #xB0A9 ?납) ; KS0-C-3333
(ucs-set-char #xB0AB ?낫) ; KS0-C-3334
(ucs-set-char #xB0AC ?났) ; KS0-C-3335
(ucs-set-char #xB0AD ?낭) ; KS0-C-3336
(ucs-set-char #xB0AE ?낮) ; KS0-C-3337
(ucs-set-char #xB0AF ?낯) ; KS0-C-3338
(ucs-set-char #xB0B1 ?낱) ; KS0-C-3339
(ucs-set-char #xB0B3 ?낳) ; KS0-C-333A
(ucs-set-char #xB0B4 ?내) ; KS0-C-333B
(ucs-set-char #xB0B5 ?낵) ; KS0-C-333C
(ucs-set-char #xB0B8 ?낸) ; KS0-C-333D
(ucs-set-char #xB0BC ?낼) ; KS0-C-333E
(ucs-set-char #xB0C4 ?냄) ; KS0-C-333F
(ucs-set-char #xB0C5 ?냅) ; KS0-C-3340
(ucs-set-char #xB0C7 ?냇) ; KS0-C-3341
(ucs-set-char #xB0C8 ?냈) ; KS0-C-3342
(ucs-set-char #xB0C9 ?냉) ; KS0-C-3343
(ucs-set-char #xB0D0 ?냐) ; KS0-C-3344
(ucs-set-char #xB0D1 ?냑) ; KS0-C-3345
(ucs-set-char #xB0D4 ?냔) ; KS0-C-3346
(ucs-set-char #xB0D8 ?냘) ; KS0-C-3347
(ucs-set-char #xB0E0 ?냠) ; KS0-C-3348
(ucs-set-char #xB0E5 ?냥) ; KS0-C-3349
(ucs-set-char #xB108 ?너) ; KS0-C-334A
(ucs-set-char #xB109 ?넉) ; KS0-C-334B
(ucs-set-char #xB10B ?넋) ; KS0-C-334C
(ucs-set-char #xB10C ?넌) ; KS0-C-334D
(ucs-set-char #xB110 ?널) ; KS0-C-334E
(ucs-set-char #xB112 ?넒) ; KS0-C-334F
(ucs-set-char #xB113 ?넓) ; KS0-C-3350
(ucs-set-char #xB118 ?넘) ; KS0-C-3351
(ucs-set-char #xB119 ?넙) ; KS0-C-3352
(ucs-set-char #xB11B ?넛) ; KS0-C-3353
(ucs-set-char #xB11C ?넜) ; KS0-C-3354
(ucs-set-char #xB11D ?넝) ; KS0-C-3355
(ucs-set-char #xB123 ?넣) ; KS0-C-3356
(ucs-set-char #xB124 ?네) ; KS0-C-3357
(ucs-set-char #xB125 ?넥) ; KS0-C-3358
(ucs-set-char #xB128 ?넨) ; KS0-C-3359
(ucs-set-char #xB12C ?넬) ; KS0-C-335A
(ucs-set-char #xB134 ?넴) ; KS0-C-335B
(ucs-set-char #xB135 ?넵) ; KS0-C-335C
(ucs-set-char #xB137 ?넷) ; KS0-C-335D
(ucs-set-char #xB138 ?넸) ; KS0-C-335E
(ucs-set-char #xB139 ?넹) ; KS0-C-335F
(ucs-set-char #xB140 ?녀) ; KS0-C-3360
(ucs-set-char #xB141 ?녁) ; KS0-C-3361
(ucs-set-char #xB144 ?년) ; KS0-C-3362
(ucs-set-char #xB148 ?녈) ; KS0-C-3363
(ucs-set-char #xB150 ?념) ; KS0-C-3364
(ucs-set-char #xB151 ?녑) ; KS0-C-3365
(ucs-set-char #xB154 ?녔) ; KS0-C-3366
(ucs-set-char #xB155 ?녕) ; KS0-C-3367
(ucs-set-char #xB158 ?녘) ; KS0-C-3368
(ucs-set-char #xB15C ?녜) ; KS0-C-3369
(ucs-set-char #xB160 ?녠) ; KS0-C-336A
(ucs-set-char #xB178 ?노) ; KS0-C-336B
(ucs-set-char #xB179 ?녹) ; KS0-C-336C
(ucs-set-char #xB17C ?논) ; KS0-C-336D
(ucs-set-char #xB180 ?놀) ; KS0-C-336E
(ucs-set-char #xB182 ?놂) ; KS0-C-336F
(ucs-set-char #xB188 ?놈) ; KS0-C-3370
(ucs-set-char #xB189 ?놉) ; KS0-C-3371
(ucs-set-char #xB18B ?놋) ; KS0-C-3372
(ucs-set-char #xB18D ?농) ; KS0-C-3373
(ucs-set-char #xB192 ?높) ; KS0-C-3374
(ucs-set-char #xB193 ?놓) ; KS0-C-3375
(ucs-set-char #xB194 ?놔) ; KS0-C-3376
(ucs-set-char #xB198 ?놘) ; KS0-C-3377
(ucs-set-char #xB19C ?놜) ; KS0-C-3378
(ucs-set-char #xB1A8 ?놨) ; KS0-C-3379
(ucs-set-char #xB1CC ?뇌) ; KS0-C-337A
(ucs-set-char #xB1D0 ?뇐) ; KS0-C-337B
(ucs-set-char #xB1D4 ?뇔) ; KS0-C-337C
(ucs-set-char #xB1DC ?뇜) ; KS0-C-337D
(ucs-set-char #xB1DD ?뇝) ; KS0-C-337E
(ucs-set-char #xB1DF ?뇟) ; KS0-C-3421
(ucs-set-char #xB1E8 ?뇨) ; KS0-C-3422
(ucs-set-char #xB1E9 ?뇩) ; KS0-C-3423
(ucs-set-char #xB1EC ?뇬) ; KS0-C-3424
(ucs-set-char #xB1F0 ?뇰) ; KS0-C-3425
(ucs-set-char #xB1F9 ?뇹) ; KS0-C-3426
(ucs-set-char #xB1FB ?뇻) ; KS0-C-3427
(ucs-set-char #xB1FD ?뇽) ; KS0-C-3428
(ucs-set-char #xB204 ?누) ; KS0-C-3429
(ucs-set-char #xB205 ?눅) ; KS0-C-342A
(ucs-set-char #xB208 ?눈) ; KS0-C-342B
(ucs-set-char #xB20B ?눋) ; KS0-C-342C
(ucs-set-char #xB20C ?눌) ; KS0-C-342D
(ucs-set-char #xB214 ?눔) ; KS0-C-342E
(ucs-set-char #xB215 ?눕) ; KS0-C-342F
(ucs-set-char #xB217 ?눗) ; KS0-C-3430
(ucs-set-char #xB219 ?눙) ; KS0-C-3431
(ucs-set-char #xB220 ?눠) ; KS0-C-3432
(ucs-set-char #xB234 ?눴) ; KS0-C-3433
(ucs-set-char #xB23C ?눼) ; KS0-C-3434
(ucs-set-char #xB258 ?뉘) ; KS0-C-3435
(ucs-set-char #xB25C ?뉜) ; KS0-C-3436
(ucs-set-char #xB260 ?뉠) ; KS0-C-3437
(ucs-set-char #xB268 ?뉨) ; KS0-C-3438
(ucs-set-char #xB269 ?뉩) ; KS0-C-3439
(ucs-set-char #xB274 ?뉴) ; KS0-C-343A
(ucs-set-char #xB275 ?뉵) ; KS0-C-343B
(ucs-set-char #xB27C ?뉼) ; KS0-C-343C
(ucs-set-char #xB284 ?늄) ; KS0-C-343D
(ucs-set-char #xB285 ?늅) ; KS0-C-343E
(ucs-set-char #xB289 ?늉) ; KS0-C-343F
(ucs-set-char #xB290 ?느) ; KS0-C-3440
(ucs-set-char #xB291 ?늑) ; KS0-C-3441
(ucs-set-char #xB294 ?는) ; KS0-C-3442
(ucs-set-char #xB298 ?늘) ; KS0-C-3443
(ucs-set-char #xB299 ?늙) ; KS0-C-3444
(ucs-set-char #xB29A ?늚) ; KS0-C-3445
(ucs-set-char #xB2A0 ?늠) ; KS0-C-3446
(ucs-set-char #xB2A1 ?늡) ; KS0-C-3447
(ucs-set-char #xB2A3 ?늣) ; KS0-C-3448
(ucs-set-char #xB2A5 ?능) ; KS0-C-3449
(ucs-set-char #xB2A6 ?늦) ; KS0-C-344A
(ucs-set-char #xB2AA ?늪) ; KS0-C-344B
(ucs-set-char #xB2AC ?늬) ; KS0-C-344C
(ucs-set-char #xB2B0 ?늰) ; KS0-C-344D
(ucs-set-char #xB2B4 ?늴) ; KS0-C-344E
(ucs-set-char #xB2C8 ?니) ; KS0-C-344F
(ucs-set-char #xB2C9 ?닉) ; KS0-C-3450
(ucs-set-char #xB2CC ?닌) ; KS0-C-3451
(ucs-set-char #xB2D0 ?닐) ; KS0-C-3452
(ucs-set-char #xB2D2 ?닒) ; KS0-C-3453
(ucs-set-char #xB2D8 ?님) ; KS0-C-3454
(ucs-set-char #xB2D9 ?닙) ; KS0-C-3455
(ucs-set-char #xB2DB ?닛) ; KS0-C-3456
(ucs-set-char #xB2DD ?닝) ; KS0-C-3457
(ucs-set-char #xB2E2 ?닢) ; KS0-C-3458
(ucs-set-char #xB2E4 ?다) ; KS0-C-3459
(ucs-set-char #xB2E5 ?닥) ; KS0-C-345A
(ucs-set-char #xB2E6 ?닦) ; KS0-C-345B
(ucs-set-char #xB2E8 ?단) ; KS0-C-345C
(ucs-set-char #xB2EB ?닫) ; KS0-C-345D
(ucs-set-char #xB2EC ?달) ; KS0-C-345E
(ucs-set-char #xB2ED ?닭) ; KS0-C-345F
(ucs-set-char #xB2EE ?닮) ; KS0-C-3460
(ucs-set-char #xB2EF ?닯) ; KS0-C-3461
(ucs-set-char #xB2F3 ?닳) ; KS0-C-3462
(ucs-set-char #xB2F4 ?담) ; KS0-C-3463
(ucs-set-char #xB2F5 ?답) ; KS0-C-3464
(ucs-set-char #xB2F7 ?닷) ; KS0-C-3465
(ucs-set-char #xB2F8 ?닸) ; KS0-C-3466
(ucs-set-char #xB2F9 ?당) ; KS0-C-3467
(ucs-set-char #xB2FA ?닺) ; KS0-C-3468
(ucs-set-char #xB2FB ?닻) ; KS0-C-3469
(ucs-set-char #xB2FF ?닿) ; KS0-C-346A
(ucs-set-char #xB300 ?대) ; KS0-C-346B
(ucs-set-char #xB301 ?댁) ; KS0-C-346C
(ucs-set-char #xB304 ?댄) ; KS0-C-346D
(ucs-set-char #xB308 ?댈) ; KS0-C-346E
(ucs-set-char #xB310 ?댐) ; KS0-C-346F
(ucs-set-char #xB311 ?댑) ; KS0-C-3470
(ucs-set-char #xB313 ?댓) ; KS0-C-3471
(ucs-set-char #xB314 ?댔) ; KS0-C-3472
(ucs-set-char #xB315 ?댕) ; KS0-C-3473
(ucs-set-char #xB31C ?댜) ; KS0-C-3474
(ucs-set-char #xB354 ?더) ; KS0-C-3475
(ucs-set-char #xB355 ?덕) ; KS0-C-3476
(ucs-set-char #xB356 ?덖) ; KS0-C-3477
(ucs-set-char #xB358 ?던) ; KS0-C-3478
(ucs-set-char #xB35B ?덛) ; KS0-C-3479
(ucs-set-char #xB35C ?덜) ; KS0-C-347A
(ucs-set-char #xB35E ?덞) ; KS0-C-347B
(ucs-set-char #xB35F ?덟) ; KS0-C-347C
(ucs-set-char #xB364 ?덤) ; KS0-C-347D
(ucs-set-char #xB365 ?덥) ; KS0-C-347E
(ucs-set-char #xB367 ?덧) ; KS0-C-3521
(ucs-set-char #xB369 ?덩) ; KS0-C-3522
(ucs-set-char #xB36B ?덫) ; KS0-C-3523
(ucs-set-char #xB36E ?덮) ; KS0-C-3524
(ucs-set-char #xB370 ?데) ; KS0-C-3525
(ucs-set-char #xB371 ?덱) ; KS0-C-3526
(ucs-set-char #xB374 ?덴) ; KS0-C-3527
(ucs-set-char #xB378 ?델) ; KS0-C-3528
(ucs-set-char #xB380 ?뎀) ; KS0-C-3529
(ucs-set-char #xB381 ?뎁) ; KS0-C-352A
(ucs-set-char #xB383 ?뎃) ; KS0-C-352B
(ucs-set-char #xB384 ?뎄) ; KS0-C-352C
(ucs-set-char #xB385 ?뎅) ; KS0-C-352D
(ucs-set-char #xB38C ?뎌) ; KS0-C-352E
(ucs-set-char #xB390 ?뎐) ; KS0-C-352F
(ucs-set-char #xB394 ?뎔) ; KS0-C-3530
(ucs-set-char #xB3A0 ?뎠) ; KS0-C-3531
(ucs-set-char #xB3A1 ?뎡) ; KS0-C-3532
(ucs-set-char #xB3A8 ?뎨) ; KS0-C-3533
(ucs-set-char #xB3AC ?뎬) ; KS0-C-3534
(ucs-set-char #xB3C4 ?도) ; KS0-C-3535
(ucs-set-char #xB3C5 ?독) ; KS0-C-3536
(ucs-set-char #xB3C8 ?돈) ; KS0-C-3537
(ucs-set-char #xB3CB ?돋) ; KS0-C-3538
(ucs-set-char #xB3CC ?돌) ; KS0-C-3539
(ucs-set-char #xB3CE ?돎) ; KS0-C-353A
(ucs-set-char #xB3D0 ?돐) ; KS0-C-353B
(ucs-set-char #xB3D4 ?돔) ; KS0-C-353C
(ucs-set-char #xB3D5 ?돕) ; KS0-C-353D
(ucs-set-char #xB3D7 ?돗) ; KS0-C-353E
(ucs-set-char #xB3D9 ?동) ; KS0-C-353F
(ucs-set-char #xB3DB ?돛) ; KS0-C-3540
(ucs-set-char #xB3DD ?돝) ; KS0-C-3541
(ucs-set-char #xB3E0 ?돠) ; KS0-C-3542
(ucs-set-char #xB3E4 ?돤) ; KS0-C-3543
(ucs-set-char #xB3E8 ?돨) ; KS0-C-3544
(ucs-set-char #xB3FC ?돼) ; KS0-C-3545
(ucs-set-char #xB410 ?됐) ; KS0-C-3546
(ucs-set-char #xB418 ?되) ; KS0-C-3547
(ucs-set-char #xB41C ?된) ; KS0-C-3548
(ucs-set-char #xB420 ?될) ; KS0-C-3549
(ucs-set-char #xB428 ?됨) ; KS0-C-354A
(ucs-set-char #xB429 ?됩) ; KS0-C-354B
(ucs-set-char #xB42B ?됫) ; KS0-C-354C
(ucs-set-char #xB434 ?됴) ; KS0-C-354D
(ucs-set-char #xB450 ?두) ; KS0-C-354E
(ucs-set-char #xB451 ?둑) ; KS0-C-354F
(ucs-set-char #xB454 ?둔) ; KS0-C-3550
(ucs-set-char #xB458 ?둘) ; KS0-C-3551
(ucs-set-char #xB460 ?둠) ; KS0-C-3552
(ucs-set-char #xB461 ?둡) ; KS0-C-3553
(ucs-set-char #xB463 ?둣) ; KS0-C-3554
(ucs-set-char #xB465 ?둥) ; KS0-C-3555
(ucs-set-char #xB46C ?둬) ; KS0-C-3556
(ucs-set-char #xB480 ?뒀) ; KS0-C-3557
(ucs-set-char #xB488 ?뒈) ; KS0-C-3558
(ucs-set-char #xB49D ?뒝) ; KS0-C-3559
(ucs-set-char #xB4A4 ?뒤) ; KS0-C-355A
(ucs-set-char #xB4A8 ?뒨) ; KS0-C-355B
(ucs-set-char #xB4AC ?뒬) ; KS0-C-355C
(ucs-set-char #xB4B5 ?뒵) ; KS0-C-355D
(ucs-set-char #xB4B7 ?뒷) ; KS0-C-355E
(ucs-set-char #xB4B9 ?뒹) ; KS0-C-355F
(ucs-set-char #xB4C0 ?듀) ; KS0-C-3560
(ucs-set-char #xB4C4 ?듄) ; KS0-C-3561
(ucs-set-char #xB4C8 ?듈) ; KS0-C-3562
(ucs-set-char #xB4D0 ?듐) ; KS0-C-3563
(ucs-set-char #xB4D5 ?듕) ; KS0-C-3564
(ucs-set-char #xB4DC ?드) ; KS0-C-3565
(ucs-set-char #xB4DD ?득) ; KS0-C-3566
(ucs-set-char #xB4E0 ?든) ; KS0-C-3567
(ucs-set-char #xB4E3 ?듣) ; KS0-C-3568
(ucs-set-char #xB4E4 ?들) ; KS0-C-3569
(ucs-set-char #xB4E6 ?듦) ; KS0-C-356A
(ucs-set-char #xB4EC ?듬) ; KS0-C-356B
(ucs-set-char #xB4ED ?듭) ; KS0-C-356C
(ucs-set-char #xB4EF ?듯) ; KS0-C-356D
(ucs-set-char #xB4F1 ?등) ; KS0-C-356E
(ucs-set-char #xB4F8 ?듸) ; KS0-C-356F
(ucs-set-char #xB514 ?디) ; KS0-C-3570
(ucs-set-char #xB515 ?딕) ; KS0-C-3571
(ucs-set-char #xB518 ?딘) ; KS0-C-3572
(ucs-set-char #xB51B ?딛) ; KS0-C-3573
(ucs-set-char #xB51C ?딜) ; KS0-C-3574
(ucs-set-char #xB524 ?딤) ; KS0-C-3575
(ucs-set-char #xB525 ?딥) ; KS0-C-3576
(ucs-set-char #xB527 ?딧) ; KS0-C-3577
(ucs-set-char #xB528 ?딨) ; KS0-C-3578
(ucs-set-char #xB529 ?딩) ; KS0-C-3579
(ucs-set-char #xB52A ?딪) ; KS0-C-357A
(ucs-set-char #xB530 ?따) ; KS0-C-357B
(ucs-set-char #xB531 ?딱) ; KS0-C-357C
(ucs-set-char #xB534 ?딴) ; KS0-C-357D
(ucs-set-char #xB538 ?딸) ; KS0-C-357E
(ucs-set-char #xB540 ?땀) ; KS0-C-3621
(ucs-set-char #xB541 ?땁) ; KS0-C-3622
(ucs-set-char #xB543 ?땃) ; KS0-C-3623
(ucs-set-char #xB544 ?땄) ; KS0-C-3624
(ucs-set-char #xB545 ?땅) ; KS0-C-3625
(ucs-set-char #xB54B ?땋) ; KS0-C-3626
(ucs-set-char #xB54C ?때) ; KS0-C-3627
(ucs-set-char #xB54D ?땍) ; KS0-C-3628
(ucs-set-char #xB550 ?땐) ; KS0-C-3629
(ucs-set-char #xB554 ?땔) ; KS0-C-362A
(ucs-set-char #xB55C ?땜) ; KS0-C-362B
(ucs-set-char #xB55D ?땝) ; KS0-C-362C
(ucs-set-char #xB55F ?땟) ; KS0-C-362D
(ucs-set-char #xB560 ?땠) ; KS0-C-362E
(ucs-set-char #xB561 ?땡) ; KS0-C-362F
(ucs-set-char #xB5A0 ?떠) ; KS0-C-3630
(ucs-set-char #xB5A1 ?떡) ; KS0-C-3631
(ucs-set-char #xB5A4 ?떤) ; KS0-C-3632
(ucs-set-char #xB5A8 ?떨) ; KS0-C-3633
(ucs-set-char #xB5AA ?떪) ; KS0-C-3634
(ucs-set-char #xB5AB ?떫) ; KS0-C-3635
(ucs-set-char #xB5B0 ?떰) ; KS0-C-3636
(ucs-set-char #xB5B1 ?떱) ; KS0-C-3637
(ucs-set-char #xB5B3 ?떳) ; KS0-C-3638
(ucs-set-char #xB5B4 ?떴) ; KS0-C-3639
(ucs-set-char #xB5B5 ?떵) ; KS0-C-363A
(ucs-set-char #xB5BB ?떻) ; KS0-C-363B
(ucs-set-char #xB5BC ?떼) ; KS0-C-363C
(ucs-set-char #xB5BD ?떽) ; KS0-C-363D
(ucs-set-char #xB5C0 ?뗀) ; KS0-C-363E
(ucs-set-char #xB5C4 ?뗄) ; KS0-C-363F
(ucs-set-char #xB5CC ?뗌) ; KS0-C-3640
(ucs-set-char #xB5CD ?뗍) ; KS0-C-3641
(ucs-set-char #xB5CF ?뗏) ; KS0-C-3642
(ucs-set-char #xB5D0 ?뗐) ; KS0-C-3643
(ucs-set-char #xB5D1 ?뗑) ; KS0-C-3644
(ucs-set-char #xB5D8 ?뗘) ; KS0-C-3645
(ucs-set-char #xB5EC ?뗬) ; KS0-C-3646
(ucs-set-char #xB610 ?또) ; KS0-C-3647
(ucs-set-char #xB611 ?똑) ; KS0-C-3648
(ucs-set-char #xB614 ?똔) ; KS0-C-3649
(ucs-set-char #xB618 ?똘) ; KS0-C-364A
(ucs-set-char #xB625 ?똥) ; KS0-C-364B
(ucs-set-char #xB62C ?똬) ; KS0-C-364C
(ucs-set-char #xB634 ?똴) ; KS0-C-364D
(ucs-set-char #xB648 ?뙈) ; KS0-C-364E
(ucs-set-char #xB664 ?뙤) ; KS0-C-364F
(ucs-set-char #xB668 ?뙨) ; KS0-C-3650
(ucs-set-char #xB69C ?뚜) ; KS0-C-3651
(ucs-set-char #xB69D ?뚝) ; KS0-C-3652
(ucs-set-char #xB6A0 ?뚠) ; KS0-C-3653
(ucs-set-char #xB6A4 ?뚤) ; KS0-C-3654
(ucs-set-char #xB6AB ?뚫) ; KS0-C-3655
(ucs-set-char #xB6AC ?뚬) ; KS0-C-3656
(ucs-set-char #xB6B1 ?뚱) ; KS0-C-3657
(ucs-set-char #xB6D4 ?뛔) ; KS0-C-3658
(ucs-set-char #xB6F0 ?뛰) ; KS0-C-3659
(ucs-set-char #xB6F4 ?뛴) ; KS0-C-365A
(ucs-set-char #xB6F8 ?뛸) ; KS0-C-365B
(ucs-set-char #xB700 ?뜀) ; KS0-C-365C
(ucs-set-char #xB701 ?뜁) ; KS0-C-365D
(ucs-set-char #xB705 ?뜅) ; KS0-C-365E
(ucs-set-char #xB728 ?뜨) ; KS0-C-365F
(ucs-set-char #xB729 ?뜩) ; KS0-C-3660
(ucs-set-char #xB72C ?뜬) ; KS0-C-3661
(ucs-set-char #xB72F ?뜯) ; KS0-C-3662
(ucs-set-char #xB730 ?뜰) ; KS0-C-3663
(ucs-set-char #xB738 ?뜸) ; KS0-C-3664
(ucs-set-char #xB739 ?뜹) ; KS0-C-3665
(ucs-set-char #xB73B ?뜻) ; KS0-C-3666
(ucs-set-char #xB744 ?띄) ; KS0-C-3667
(ucs-set-char #xB748 ?띈) ; KS0-C-3668
(ucs-set-char #xB74C ?띌) ; KS0-C-3669
(ucs-set-char #xB754 ?띔) ; KS0-C-366A
(ucs-set-char #xB755 ?띕) ; KS0-C-366B
(ucs-set-char #xB760 ?띠) ; KS0-C-366C
(ucs-set-char #xB764 ?띤) ; KS0-C-366D
(ucs-set-char #xB768 ?띨) ; KS0-C-366E
(ucs-set-char #xB770 ?띰) ; KS0-C-366F
(ucs-set-char #xB771 ?띱) ; KS0-C-3670
(ucs-set-char #xB773 ?띳) ; KS0-C-3671
(ucs-set-char #xB775 ?띵) ; KS0-C-3672
(ucs-set-char #xB77C ?라) ; KS0-C-3673
(ucs-set-char #xB77D ?락) ; KS0-C-3674
(ucs-set-char #xB780 ?란) ; KS0-C-3675
(ucs-set-char #xB784 ?랄) ; KS0-C-3676
(ucs-set-char #xB78C ?람) ; KS0-C-3677
(ucs-set-char #xB78D ?랍) ; KS0-C-3678
(ucs-set-char #xB78F ?랏) ; KS0-C-3679
(ucs-set-char #xB790 ?랐) ; KS0-C-367A
(ucs-set-char #xB791 ?랑) ; KS0-C-367B
(ucs-set-char #xB792 ?랒) ; KS0-C-367C
(ucs-set-char #xB796 ?랖) ; KS0-C-367D
(ucs-set-char #xB797 ?랗) ; KS0-C-367E
(ucs-set-char #xB798 ?래) ; KS0-C-3721
(ucs-set-char #xB799 ?랙) ; KS0-C-3722
(ucs-set-char #xB79C ?랜) ; KS0-C-3723
(ucs-set-char #xB7A0 ?랠) ; KS0-C-3724
(ucs-set-char #xB7A8 ?램) ; KS0-C-3725
(ucs-set-char #xB7A9 ?랩) ; KS0-C-3726
(ucs-set-char #xB7AB ?랫) ; KS0-C-3727
(ucs-set-char #xB7AC ?랬) ; KS0-C-3728
(ucs-set-char #xB7AD ?랭) ; KS0-C-3729
(ucs-set-char #xB7B4 ?랴) ; KS0-C-372A
(ucs-set-char #xB7B5 ?략) ; KS0-C-372B
(ucs-set-char #xB7B8 ?랸) ; KS0-C-372C
(ucs-set-char #xB7C7 ?럇) ; KS0-C-372D
(ucs-set-char #xB7C9 ?량) ; KS0-C-372E
(ucs-set-char #xB7EC ?러) ; KS0-C-372F
(ucs-set-char #xB7ED ?럭) ; KS0-C-3730
(ucs-set-char #xB7F0 ?런) ; KS0-C-3731
(ucs-set-char #xB7F4 ?럴) ; KS0-C-3732
(ucs-set-char #xB7FC ?럼) ; KS0-C-3733
(ucs-set-char #xB7FD ?럽) ; KS0-C-3734
(ucs-set-char #xB7FF ?럿) ; KS0-C-3735
(ucs-set-char #xB800 ?렀) ; KS0-C-3736
(ucs-set-char #xB801 ?렁) ; KS0-C-3737
(ucs-set-char #xB807 ?렇) ; KS0-C-3738
(ucs-set-char #xB808 ?레) ; KS0-C-3739
(ucs-set-char #xB809 ?렉) ; KS0-C-373A
(ucs-set-char #xB80C ?렌) ; KS0-C-373B
(ucs-set-char #xB810 ?렐) ; KS0-C-373C
(ucs-set-char #xB818 ?렘) ; KS0-C-373D
(ucs-set-char #xB819 ?렙) ; KS0-C-373E
(ucs-set-char #xB81B ?렛) ; KS0-C-373F
(ucs-set-char #xB81D ?렝) ; KS0-C-3740
(ucs-set-char #xB824 ?려) ; KS0-C-3741
(ucs-set-char #xB825 ?력) ; KS0-C-3742
(ucs-set-char #xB828 ?련) ; KS0-C-3743
(ucs-set-char #xB82C ?렬) ; KS0-C-3744
(ucs-set-char #xB834 ?렴) ; KS0-C-3745
(ucs-set-char #xB835 ?렵) ; KS0-C-3746
(ucs-set-char #xB837 ?렷) ; KS0-C-3747
(ucs-set-char #xB838 ?렸) ; KS0-C-3748
(ucs-set-char #xB839 ?령) ; KS0-C-3749
(ucs-set-char #xB840 ?례) ; KS0-C-374A
(ucs-set-char #xB844 ?롄) ; KS0-C-374B
(ucs-set-char #xB851 ?롑) ; KS0-C-374C
(ucs-set-char #xB853 ?롓) ; KS0-C-374D
(ucs-set-char #xB85C ?로) ; KS0-C-374E
(ucs-set-char #xB85D ?록) ; KS0-C-374F
(ucs-set-char #xB860 ?론) ; KS0-C-3750
(ucs-set-char #xB864 ?롤) ; KS0-C-3751
(ucs-set-char #xB86C ?롬) ; KS0-C-3752
(ucs-set-char #xB86D ?롭) ; KS0-C-3753
(ucs-set-char #xB86F ?롯) ; KS0-C-3754
(ucs-set-char #xB871 ?롱) ; KS0-C-3755
(ucs-set-char #xB878 ?롸) ; KS0-C-3756
(ucs-set-char #xB87C ?롼) ; KS0-C-3757
(ucs-set-char #xB88D ?뢍) ; KS0-C-3758
(ucs-set-char #xB8A8 ?뢨) ; KS0-C-3759
(ucs-set-char #xB8B0 ?뢰) ; KS0-C-375A
(ucs-set-char #xB8B4 ?뢴) ; KS0-C-375B
(ucs-set-char #xB8B8 ?뢸) ; KS0-C-375C
(ucs-set-char #xB8C0 ?룀) ; KS0-C-375D
(ucs-set-char #xB8C1 ?룁) ; KS0-C-375E
(ucs-set-char #xB8C3 ?룃) ; KS0-C-375F
(ucs-set-char #xB8C5 ?룅) ; KS0-C-3760
(ucs-set-char #xB8CC ?료) ; KS0-C-3761
(ucs-set-char #xB8D0 ?룐) ; KS0-C-3762
(ucs-set-char #xB8D4 ?룔) ; KS0-C-3763
(ucs-set-char #xB8DD ?룝) ; KS0-C-3764
(ucs-set-char #xB8DF ?룟) ; KS0-C-3765
(ucs-set-char #xB8E1 ?룡) ; KS0-C-3766
(ucs-set-char #xB8E8 ?루) ; KS0-C-3767
(ucs-set-char #xB8E9 ?룩) ; KS0-C-3768
(ucs-set-char #xB8EC ?룬) ; KS0-C-3769
(ucs-set-char #xB8F0 ?룰) ; KS0-C-376A
(ucs-set-char #xB8F8 ?룸) ; KS0-C-376B
(ucs-set-char #xB8F9 ?룹) ; KS0-C-376C
(ucs-set-char #xB8FB ?룻) ; KS0-C-376D
(ucs-set-char #xB8FD ?룽) ; KS0-C-376E
(ucs-set-char #xB904 ?뤄) ; KS0-C-376F
(ucs-set-char #xB918 ?뤘) ; KS0-C-3770
(ucs-set-char #xB920 ?뤠) ; KS0-C-3771
(ucs-set-char #xB93C ?뤼) ; KS0-C-3772
(ucs-set-char #xB93D ?뤽) ; KS0-C-3773
(ucs-set-char #xB940 ?륀) ; KS0-C-3774
(ucs-set-char #xB944 ?륄) ; KS0-C-3775
(ucs-set-char #xB94C ?륌) ; KS0-C-3776
(ucs-set-char #xB94F ?륏) ; KS0-C-3777
(ucs-set-char #xB951 ?륑) ; KS0-C-3778
(ucs-set-char #xB958 ?류) ; KS0-C-3779
(ucs-set-char #xB959 ?륙) ; KS0-C-377A
(ucs-set-char #xB95C ?륜) ; KS0-C-377B
(ucs-set-char #xB960 ?률) ; KS0-C-377C
(ucs-set-char #xB968 ?륨) ; KS0-C-377D
(ucs-set-char #xB969 ?륩) ; KS0-C-377E
(ucs-set-char #xB96B ?륫) ; KS0-C-3821
(ucs-set-char #xB96D ?륭) ; KS0-C-3822
(ucs-set-char #xB974 ?르) ; KS0-C-3823
(ucs-set-char #xB975 ?륵) ; KS0-C-3824
(ucs-set-char #xB978 ?른) ; KS0-C-3825
(ucs-set-char #xB97C ?를) ; KS0-C-3826
(ucs-set-char #xB984 ?름) ; KS0-C-3827
(ucs-set-char #xB985 ?릅) ; KS0-C-3828
(ucs-set-char #xB987 ?릇) ; KS0-C-3829
(ucs-set-char #xB989 ?릉) ; KS0-C-382A
(ucs-set-char #xB98A ?릊) ; KS0-C-382B
(ucs-set-char #xB98D ?릍) ; KS0-C-382C
(ucs-set-char #xB98E ?릎) ; KS0-C-382D
(ucs-set-char #xB9AC ?리) ; KS0-C-382E
(ucs-set-char #xB9AD ?릭) ; KS0-C-382F
(ucs-set-char #xB9B0 ?린) ; KS0-C-3830
(ucs-set-char #xB9B4 ?릴) ; KS0-C-3831
(ucs-set-char #xB9BC ?림) ; KS0-C-3832
(ucs-set-char #xB9BD ?립) ; KS0-C-3833
(ucs-set-char #xB9BF ?릿) ; KS0-C-3834
(ucs-set-char #xB9C1 ?링) ; KS0-C-3835
(ucs-set-char #xB9C8 ?마) ; KS0-C-3836
(ucs-set-char #xB9C9 ?막) ; KS0-C-3837
(ucs-set-char #xB9CC ?만) ; KS0-C-3838
(ucs-set-char #xB9CE ?많) ; KS0-C-3839
(ucs-set-char #xB9CF ?맏) ; KS0-C-383A
(ucs-set-char #xB9D0 ?말) ; KS0-C-383B
(ucs-set-char #xB9D1 ?맑) ; KS0-C-383C
(ucs-set-char #xB9D2 ?맒) ; KS0-C-383D
(ucs-set-char #xB9D8 ?맘) ; KS0-C-383E
(ucs-set-char #xB9D9 ?맙) ; KS0-C-383F
(ucs-set-char #xB9DB ?맛) ; KS0-C-3840
(ucs-set-char #xB9DD ?망) ; KS0-C-3841
(ucs-set-char #xB9DE ?맞) ; KS0-C-3842
(ucs-set-char #xB9E1 ?맡) ; KS0-C-3843
(ucs-set-char #xB9E3 ?맣) ; KS0-C-3844
(ucs-set-char #xB9E4 ?매) ; KS0-C-3845
(ucs-set-char #xB9E5 ?맥) ; KS0-C-3846
(ucs-set-char #xB9E8 ?맨) ; KS0-C-3847
(ucs-set-char #xB9EC ?맬) ; KS0-C-3848
(ucs-set-char #xB9F4 ?맴) ; KS0-C-3849
(ucs-set-char #xB9F5 ?맵) ; KS0-C-384A
(ucs-set-char #xB9F7 ?맷) ; KS0-C-384B
(ucs-set-char #xB9F8 ?맸) ; KS0-C-384C
(ucs-set-char #xB9F9 ?맹) ; KS0-C-384D
(ucs-set-char #xB9FA ?맺) ; KS0-C-384E
(ucs-set-char #xBA00 ?먀) ; KS0-C-384F
(ucs-set-char #xBA01 ?먁) ; KS0-C-3850
(ucs-set-char #xBA08 ?먈) ; KS0-C-3851
(ucs-set-char #xBA15 ?먕) ; KS0-C-3852
(ucs-set-char #xBA38 ?머) ; KS0-C-3853
(ucs-set-char #xBA39 ?먹) ; KS0-C-3854
(ucs-set-char #xBA3C ?먼) ; KS0-C-3855
(ucs-set-char #xBA40 ?멀) ; KS0-C-3856
(ucs-set-char #xBA42 ?멂) ; KS0-C-3857
(ucs-set-char #xBA48 ?멈) ; KS0-C-3858
(ucs-set-char #xBA49 ?멉) ; KS0-C-3859
(ucs-set-char #xBA4B ?멋) ; KS0-C-385A
(ucs-set-char #xBA4D ?멍) ; KS0-C-385B
(ucs-set-char #xBA4E ?멎) ; KS0-C-385C
(ucs-set-char #xBA53 ?멓) ; KS0-C-385D
(ucs-set-char #xBA54 ?메) ; KS0-C-385E
(ucs-set-char #xBA55 ?멕) ; KS0-C-385F
(ucs-set-char #xBA58 ?멘) ; KS0-C-3860
(ucs-set-char #xBA5C ?멜) ; KS0-C-3861
(ucs-set-char #xBA64 ?멤) ; KS0-C-3862
(ucs-set-char #xBA65 ?멥) ; KS0-C-3863
(ucs-set-char #xBA67 ?멧) ; KS0-C-3864
(ucs-set-char #xBA68 ?멨) ; KS0-C-3865
(ucs-set-char #xBA69 ?멩) ; KS0-C-3866
(ucs-set-char #xBA70 ?며) ; KS0-C-3867
(ucs-set-char #xBA71 ?멱) ; KS0-C-3868
(ucs-set-char #xBA74 ?면) ; KS0-C-3869
(ucs-set-char #xBA78 ?멸) ; KS0-C-386A
(ucs-set-char #xBA83 ?몃) ; KS0-C-386B
(ucs-set-char #xBA84 ?몄) ; KS0-C-386C
(ucs-set-char #xBA85 ?명) ; KS0-C-386D
(ucs-set-char #xBA87 ?몇) ; KS0-C-386E
(ucs-set-char #xBA8C ?몌) ; KS0-C-386F
(ucs-set-char #xBAA8 ?모) ; KS0-C-3870
(ucs-set-char #xBAA9 ?목) ; KS0-C-3871
(ucs-set-char #xBAAB ?몫) ; KS0-C-3872
(ucs-set-char #xBAAC ?몬) ; KS0-C-3873
(ucs-set-char #xBAB0 ?몰) ; KS0-C-3874
(ucs-set-char #xBAB2 ?몲) ; KS0-C-3875
(ucs-set-char #xBAB8 ?몸) ; KS0-C-3876
(ucs-set-char #xBAB9 ?몹) ; KS0-C-3877
(ucs-set-char #xBABB ?못) ; KS0-C-3878
(ucs-set-char #xBABD ?몽) ; KS0-C-3879
(ucs-set-char #xBAC4 ?뫄) ; KS0-C-387A
(ucs-set-char #xBAC8 ?뫈) ; KS0-C-387B
(ucs-set-char #xBAD8 ?뫘) ; KS0-C-387C
(ucs-set-char #xBAD9 ?뫙) ; KS0-C-387D
(ucs-set-char #xBAFC ?뫼) ; KS0-C-387E
(ucs-set-char #xBB00 ?묀) ; KS0-C-3921
(ucs-set-char #xBB04 ?묄) ; KS0-C-3922
(ucs-set-char #xBB0D ?묍) ; KS0-C-3923
(ucs-set-char #xBB0F ?묏) ; KS0-C-3924
(ucs-set-char #xBB11 ?묑) ; KS0-C-3925
(ucs-set-char #xBB18 ?묘) ; KS0-C-3926
(ucs-set-char #xBB1C ?묜) ; KS0-C-3927
(ucs-set-char #xBB20 ?묠) ; KS0-C-3928
(ucs-set-char #xBB29 ?묩) ; KS0-C-3929
(ucs-set-char #xBB2B ?묫) ; KS0-C-392A
(ucs-set-char #xBB34 ?무) ; KS0-C-392B
(ucs-set-char #xBB35 ?묵) ; KS0-C-392C
(ucs-set-char #xBB36 ?묶) ; KS0-C-392D
(ucs-set-char #xBB38 ?문) ; KS0-C-392E
(ucs-set-char #xBB3B ?묻) ; KS0-C-392F
(ucs-set-char #xBB3C ?물) ; KS0-C-3930
(ucs-set-char #xBB3D ?묽) ; KS0-C-3931
(ucs-set-char #xBB3E ?묾) ; KS0-C-3932
(ucs-set-char #xBB44 ?뭄) ; KS0-C-3933
(ucs-set-char #xBB45 ?뭅) ; KS0-C-3934
(ucs-set-char #xBB47 ?뭇) ; KS0-C-3935
(ucs-set-char #xBB49 ?뭉) ; KS0-C-3936
(ucs-set-char #xBB4D ?뭍) ; KS0-C-3937
(ucs-set-char #xBB4F ?뭏) ; KS0-C-3938
(ucs-set-char #xBB50 ?뭐) ; KS0-C-3939
(ucs-set-char #xBB54 ?뭔) ; KS0-C-393A
(ucs-set-char #xBB58 ?뭘) ; KS0-C-393B
(ucs-set-char #xBB61 ?뭡) ; KS0-C-393C
(ucs-set-char #xBB63 ?뭣) ; KS0-C-393D
(ucs-set-char #xBB6C ?뭬) ; KS0-C-393E
(ucs-set-char #xBB88 ?뮈) ; KS0-C-393F
(ucs-set-char #xBB8C ?뮌) ; KS0-C-3940
(ucs-set-char #xBB90 ?뮐) ; KS0-C-3941
(ucs-set-char #xBBA4 ?뮤) ; KS0-C-3942
(ucs-set-char #xBBA8 ?뮨) ; KS0-C-3943
(ucs-set-char #xBBAC ?뮬) ; KS0-C-3944
(ucs-set-char #xBBB4 ?뮴) ; KS0-C-3945
(ucs-set-char #xBBB7 ?뮷) ; KS0-C-3946
(ucs-set-char #xBBC0 ?므) ; KS0-C-3947
(ucs-set-char #xBBC4 ?믄) ; KS0-C-3948
(ucs-set-char #xBBC8 ?믈) ; KS0-C-3949
(ucs-set-char #xBBD0 ?믐) ; KS0-C-394A
(ucs-set-char #xBBD3 ?믓) ; KS0-C-394B
(ucs-set-char #xBBF8 ?미) ; KS0-C-394C
(ucs-set-char #xBBF9 ?믹) ; KS0-C-394D
(ucs-set-char #xBBFC ?민) ; KS0-C-394E
(ucs-set-char #xBBFF ?믿) ; KS0-C-394F
(ucs-set-char #xBC00 ?밀) ; KS0-C-3950
(ucs-set-char #xBC02 ?밂) ; KS0-C-3951
(ucs-set-char #xBC08 ?밈) ; KS0-C-3952
(ucs-set-char #xBC09 ?밉) ; KS0-C-3953
(ucs-set-char #xBC0B ?밋) ; KS0-C-3954
(ucs-set-char #xBC0C ?밌) ; KS0-C-3955
(ucs-set-char #xBC0D ?밍) ; KS0-C-3956
(ucs-set-char #xBC0F ?및) ; KS0-C-3957
(ucs-set-char #xBC11 ?밑) ; KS0-C-3958
(ucs-set-char #xBC14 ?바) ; KS0-C-3959
(ucs-set-char #xBC15 ?박) ; KS0-C-395A
(ucs-set-char #xBC16 ?밖) ; KS0-C-395B
(ucs-set-char #xBC17 ?밗) ; KS0-C-395C
(ucs-set-char #xBC18 ?반) ; KS0-C-395D
(ucs-set-char #xBC1B ?받) ; KS0-C-395E
(ucs-set-char #xBC1C ?발) ; KS0-C-395F
(ucs-set-char #xBC1D ?밝) ; KS0-C-3960
(ucs-set-char #xBC1E ?밞) ; KS0-C-3961
(ucs-set-char #xBC1F ?밟) ; KS0-C-3962
(ucs-set-char #xBC24 ?밤) ; KS0-C-3963
(ucs-set-char #xBC25 ?밥) ; KS0-C-3964
(ucs-set-char #xBC27 ?밧) ; KS0-C-3965
(ucs-set-char #xBC29 ?방) ; KS0-C-3966
(ucs-set-char #xBC2D ?밭) ; KS0-C-3967
(ucs-set-char #xBC30 ?배) ; KS0-C-3968
(ucs-set-char #xBC31 ?백) ; KS0-C-3969
(ucs-set-char #xBC34 ?밴) ; KS0-C-396A
(ucs-set-char #xBC38 ?밸) ; KS0-C-396B
(ucs-set-char #xBC40 ?뱀) ; KS0-C-396C
(ucs-set-char #xBC41 ?뱁) ; KS0-C-396D
(ucs-set-char #xBC43 ?뱃) ; KS0-C-396E
(ucs-set-char #xBC44 ?뱄) ; KS0-C-396F
(ucs-set-char #xBC45 ?뱅) ; KS0-C-3970
(ucs-set-char #xBC49 ?뱉) ; KS0-C-3971
(ucs-set-char #xBC4C ?뱌) ; KS0-C-3972
(ucs-set-char #xBC4D ?뱍) ; KS0-C-3973
(ucs-set-char #xBC50 ?뱐) ; KS0-C-3974
(ucs-set-char #xBC5D ?뱝) ; KS0-C-3975
(ucs-set-char #xBC84 ?버) ; KS0-C-3976
(ucs-set-char #xBC85 ?벅) ; KS0-C-3977
(ucs-set-char #xBC88 ?번) ; KS0-C-3978
(ucs-set-char #xBC8B ?벋) ; KS0-C-3979
(ucs-set-char #xBC8C ?벌) ; KS0-C-397A
(ucs-set-char #xBC8E ?벎) ; KS0-C-397B
(ucs-set-char #xBC94 ?범) ; KS0-C-397C
(ucs-set-char #xBC95 ?법) ; KS0-C-397D
(ucs-set-char #xBC97 ?벗) ; KS0-C-397E
(ucs-set-char #xBC99 ?벙) ; KS0-C-3A21
(ucs-set-char #xBC9A ?벚) ; KS0-C-3A22
(ucs-set-char #xBCA0 ?베) ; KS0-C-3A23
(ucs-set-char #xBCA1 ?벡) ; KS0-C-3A24
(ucs-set-char #xBCA4 ?벤) ; KS0-C-3A25
(ucs-set-char #xBCA7 ?벧) ; KS0-C-3A26
(ucs-set-char #xBCA8 ?벨) ; KS0-C-3A27
(ucs-set-char #xBCB0 ?벰) ; KS0-C-3A28
(ucs-set-char #xBCB1 ?벱) ; KS0-C-3A29
(ucs-set-char #xBCB3 ?벳) ; KS0-C-3A2A
(ucs-set-char #xBCB4 ?벴) ; KS0-C-3A2B
(ucs-set-char #xBCB5 ?벵) ; KS0-C-3A2C
(ucs-set-char #xBCBC ?벼) ; KS0-C-3A2D
(ucs-set-char #xBCBD ?벽) ; KS0-C-3A2E
(ucs-set-char #xBCC0 ?변) ; KS0-C-3A2F
(ucs-set-char #xBCC4 ?별) ; KS0-C-3A30
(ucs-set-char #xBCCD ?볍) ; KS0-C-3A31
(ucs-set-char #xBCCF ?볏) ; KS0-C-3A32
(ucs-set-char #xBCD0 ?볐) ; KS0-C-3A33
(ucs-set-char #xBCD1 ?병) ; KS0-C-3A34
(ucs-set-char #xBCD5 ?볕) ; KS0-C-3A35
(ucs-set-char #xBCD8 ?볘) ; KS0-C-3A36
(ucs-set-char #xBCDC ?볜) ; KS0-C-3A37
(ucs-set-char #xBCF4 ?보) ; KS0-C-3A38
(ucs-set-char #xBCF5 ?복) ; KS0-C-3A39
(ucs-set-char #xBCF6 ?볶) ; KS0-C-3A3A
(ucs-set-char #xBCF8 ?본) ; KS0-C-3A3B
(ucs-set-char #xBCFC ?볼) ; KS0-C-3A3C
(ucs-set-char #xBD04 ?봄) ; KS0-C-3A3D
(ucs-set-char #xBD05 ?봅) ; KS0-C-3A3E
(ucs-set-char #xBD07 ?봇) ; KS0-C-3A3F
(ucs-set-char #xBD09 ?봉) ; KS0-C-3A40
(ucs-set-char #xBD10 ?봐) ; KS0-C-3A41
(ucs-set-char #xBD14 ?봔) ; KS0-C-3A42
(ucs-set-char #xBD24 ?봤) ; KS0-C-3A43
(ucs-set-char #xBD2C ?봬) ; KS0-C-3A44
(ucs-set-char #xBD40 ?뵀) ; KS0-C-3A45
(ucs-set-char #xBD48 ?뵈) ; KS0-C-3A46
(ucs-set-char #xBD49 ?뵉) ; KS0-C-3A47
(ucs-set-char #xBD4C ?뵌) ; KS0-C-3A48
(ucs-set-char #xBD50 ?뵐) ; KS0-C-3A49
(ucs-set-char #xBD58 ?뵘) ; KS0-C-3A4A
(ucs-set-char #xBD59 ?뵙) ; KS0-C-3A4B
(ucs-set-char #xBD64 ?뵤) ; KS0-C-3A4C
(ucs-set-char #xBD68 ?뵨) ; KS0-C-3A4D
(ucs-set-char #xBD80 ?부) ; KS0-C-3A4E
(ucs-set-char #xBD81 ?북) ; KS0-C-3A4F
(ucs-set-char #xBD84 ?분) ; KS0-C-3A50
(ucs-set-char #xBD87 ?붇) ; KS0-C-3A51
(ucs-set-char #xBD88 ?불) ; KS0-C-3A52
(ucs-set-char #xBD89 ?붉) ; KS0-C-3A53
(ucs-set-char #xBD8A ?붊) ; KS0-C-3A54
(ucs-set-char #xBD90 ?붐) ; KS0-C-3A55
(ucs-set-char #xBD91 ?붑) ; KS0-C-3A56
(ucs-set-char #xBD93 ?붓) ; KS0-C-3A57
(ucs-set-char #xBD95 ?붕) ; KS0-C-3A58
(ucs-set-char #xBD99 ?붙) ; KS0-C-3A59
(ucs-set-char #xBD9A ?붚) ; KS0-C-3A5A
(ucs-set-char #xBD9C ?붜) ; KS0-C-3A5B
(ucs-set-char #xBDA4 ?붤) ; KS0-C-3A5C
(ucs-set-char #xBDB0 ?붰) ; KS0-C-3A5D
(ucs-set-char #xBDB8 ?붸) ; KS0-C-3A5E
(ucs-set-char #xBDD4 ?뷔) ; KS0-C-3A5F
(ucs-set-char #xBDD5 ?뷕) ; KS0-C-3A60
(ucs-set-char #xBDD8 ?뷘) ; KS0-C-3A61
(ucs-set-char #xBDDC ?뷜) ; KS0-C-3A62
(ucs-set-char #xBDE9 ?뷩) ; KS0-C-3A63
(ucs-set-char #xBDF0 ?뷰) ; KS0-C-3A64
(ucs-set-char #xBDF4 ?뷴) ; KS0-C-3A65
(ucs-set-char #xBDF8 ?뷸) ; KS0-C-3A66
(ucs-set-char #xBE00 ?븀) ; KS0-C-3A67
(ucs-set-char #xBE03 ?븃) ; KS0-C-3A68
(ucs-set-char #xBE05 ?븅) ; KS0-C-3A69
(ucs-set-char #xBE0C ?브) ; KS0-C-3A6A
(ucs-set-char #xBE0D ?븍) ; KS0-C-3A6B
(ucs-set-char #xBE10 ?븐) ; KS0-C-3A6C
(ucs-set-char #xBE14 ?블) ; KS0-C-3A6D
(ucs-set-char #xBE1C ?븜) ; KS0-C-3A6E
(ucs-set-char #xBE1D ?븝) ; KS0-C-3A6F
(ucs-set-char #xBE1F ?븟) ; KS0-C-3A70
(ucs-set-char #xBE44 ?비) ; KS0-C-3A71
(ucs-set-char #xBE45 ?빅) ; KS0-C-3A72
(ucs-set-char #xBE48 ?빈) ; KS0-C-3A73
(ucs-set-char #xBE4C ?빌) ; KS0-C-3A74
(ucs-set-char #xBE4E ?빎) ; KS0-C-3A75
(ucs-set-char #xBE54 ?빔) ; KS0-C-3A76
(ucs-set-char #xBE55 ?빕) ; KS0-C-3A77
(ucs-set-char #xBE57 ?빗) ; KS0-C-3A78
(ucs-set-char #xBE59 ?빙) ; KS0-C-3A79
(ucs-set-char #xBE5A ?빚) ; KS0-C-3A7A
(ucs-set-char #xBE5B ?빛) ; KS0-C-3A7B
(ucs-set-char #xBE60 ?빠) ; KS0-C-3A7C
(ucs-set-char #xBE61 ?빡) ; KS0-C-3A7D
(ucs-set-char #xBE64 ?빤) ; KS0-C-3A7E
(ucs-set-char #xBE68 ?빨) ; KS0-C-3B21
(ucs-set-char #xBE6A ?빪) ; KS0-C-3B22
(ucs-set-char #xBE70 ?빰) ; KS0-C-3B23
(ucs-set-char #xBE71 ?빱) ; KS0-C-3B24
(ucs-set-char #xBE73 ?빳) ; KS0-C-3B25
(ucs-set-char #xBE74 ?빴) ; KS0-C-3B26
(ucs-set-char #xBE75 ?빵) ; KS0-C-3B27
(ucs-set-char #xBE7B ?빻) ; KS0-C-3B28
(ucs-set-char #xBE7C ?빼) ; KS0-C-3B29
(ucs-set-char #xBE7D ?빽) ; KS0-C-3B2A
(ucs-set-char #xBE80 ?뺀) ; KS0-C-3B2B
(ucs-set-char #xBE84 ?뺄) ; KS0-C-3B2C
(ucs-set-char #xBE8C ?뺌) ; KS0-C-3B2D
(ucs-set-char #xBE8D ?뺍) ; KS0-C-3B2E
(ucs-set-char #xBE8F ?뺏) ; KS0-C-3B2F
(ucs-set-char #xBE90 ?뺐) ; KS0-C-3B30
(ucs-set-char #xBE91 ?뺑) ; KS0-C-3B31
(ucs-set-char #xBE98 ?뺘) ; KS0-C-3B32
(ucs-set-char #xBE99 ?뺙) ; KS0-C-3B33
(ucs-set-char #xBEA8 ?뺨) ; KS0-C-3B34
(ucs-set-char #xBED0 ?뻐) ; KS0-C-3B35
(ucs-set-char #xBED1 ?뻑) ; KS0-C-3B36
(ucs-set-char #xBED4 ?뻔) ; KS0-C-3B37
(ucs-set-char #xBED7 ?뻗) ; KS0-C-3B38
(ucs-set-char #xBED8 ?뻘) ; KS0-C-3B39
(ucs-set-char #xBEE0 ?뻠) ; KS0-C-3B3A
(ucs-set-char #xBEE3 ?뻣) ; KS0-C-3B3B
(ucs-set-char #xBEE4 ?뻤) ; KS0-C-3B3C
(ucs-set-char #xBEE5 ?뻥) ; KS0-C-3B3D
(ucs-set-char #xBEEC ?뻬) ; KS0-C-3B3E
(ucs-set-char #xBF01 ?뼁) ; KS0-C-3B3F
(ucs-set-char #xBF08 ?뼈) ; KS0-C-3B40
(ucs-set-char #xBF09 ?뼉) ; KS0-C-3B41
(ucs-set-char #xBF18 ?뼘) ; KS0-C-3B42
(ucs-set-char #xBF19 ?뼙) ; KS0-C-3B43
(ucs-set-char #xBF1B ?뼛) ; KS0-C-3B44
(ucs-set-char #xBF1C ?뼜) ; KS0-C-3B45
(ucs-set-char #xBF1D ?뼝) ; KS0-C-3B46
(ucs-set-char #xBF40 ?뽀) ; KS0-C-3B47
(ucs-set-char #xBF41 ?뽁) ; KS0-C-3B48
(ucs-set-char #xBF44 ?뽄) ; KS0-C-3B49
(ucs-set-char #xBF48 ?뽈) ; KS0-C-3B4A
(ucs-set-char #xBF50 ?뽐) ; KS0-C-3B4B
(ucs-set-char #xBF51 ?뽑) ; KS0-C-3B4C
(ucs-set-char #xBF55 ?뽕) ; KS0-C-3B4D
(ucs-set-char #xBF94 ?뾔) ; KS0-C-3B4E
(ucs-set-char #xBFB0 ?뾰) ; KS0-C-3B4F
(ucs-set-char #xBFC5 ?뿅) ; KS0-C-3B50
(ucs-set-char #xBFCC ?뿌) ; KS0-C-3B51
(ucs-set-char #xBFCD ?뿍) ; KS0-C-3B52
(ucs-set-char #xBFD0 ?뿐) ; KS0-C-3B53
(ucs-set-char #xBFD4 ?뿔) ; KS0-C-3B54
(ucs-set-char #xBFDC ?뿜) ; KS0-C-3B55
(ucs-set-char #xBFDF ?뿟) ; KS0-C-3B56
(ucs-set-char #xBFE1 ?뿡) ; KS0-C-3B57
(ucs-set-char #xC03C ?쀼) ; KS0-C-3B58
(ucs-set-char #xC051 ?쁑) ; KS0-C-3B59
(ucs-set-char #xC058 ?쁘) ; KS0-C-3B5A
(ucs-set-char #xC05C ?쁜) ; KS0-C-3B5B
(ucs-set-char #xC060 ?쁠) ; KS0-C-3B5C
(ucs-set-char #xC068 ?쁨) ; KS0-C-3B5D
(ucs-set-char #xC069 ?쁩) ; KS0-C-3B5E
(ucs-set-char #xC090 ?삐) ; KS0-C-3B5F
(ucs-set-char #xC091 ?삑) ; KS0-C-3B60
(ucs-set-char #xC094 ?삔) ; KS0-C-3B61
(ucs-set-char #xC098 ?삘) ; KS0-C-3B62
(ucs-set-char #xC0A0 ?삠) ; KS0-C-3B63
(ucs-set-char #xC0A1 ?삡) ; KS0-C-3B64
(ucs-set-char #xC0A3 ?삣) ; KS0-C-3B65
(ucs-set-char #xC0A5 ?삥) ; KS0-C-3B66
(ucs-set-char #xC0AC ?사) ; KS0-C-3B67
(ucs-set-char #xC0AD ?삭) ; KS0-C-3B68
(ucs-set-char #xC0AF ?삯) ; KS0-C-3B69
(ucs-set-char #xC0B0 ?산) ; KS0-C-3B6A
(ucs-set-char #xC0B3 ?삳) ; KS0-C-3B6B
(ucs-set-char #xC0B4 ?살) ; KS0-C-3B6C
(ucs-set-char #xC0B5 ?삵) ; KS0-C-3B6D
(ucs-set-char #xC0B6 ?삶) ; KS0-C-3B6E
(ucs-set-char #xC0BC ?삼) ; KS0-C-3B6F
(ucs-set-char #xC0BD ?삽) ; KS0-C-3B70
(ucs-set-char #xC0BF ?삿) ; KS0-C-3B71
(ucs-set-char #xC0C0 ?샀) ; KS0-C-3B72
(ucs-set-char #xC0C1 ?상) ; KS0-C-3B73
(ucs-set-char #xC0C5 ?샅) ; KS0-C-3B74
(ucs-set-char #xC0C8 ?새) ; KS0-C-3B75
(ucs-set-char #xC0C9 ?색) ; KS0-C-3B76
(ucs-set-char #xC0CC ?샌) ; KS0-C-3B77
(ucs-set-char #xC0D0 ?샐) ; KS0-C-3B78
(ucs-set-char #xC0D8 ?샘) ; KS0-C-3B79
(ucs-set-char #xC0D9 ?샙) ; KS0-C-3B7A
(ucs-set-char #xC0DB ?샛) ; KS0-C-3B7B
(ucs-set-char #xC0DC ?샜) ; KS0-C-3B7C
(ucs-set-char #xC0DD ?생) ; KS0-C-3B7D
(ucs-set-char #xC0E4 ?샤) ; KS0-C-3B7E
(ucs-set-char #xC0E5 ?샥) ; KS0-C-3C21
(ucs-set-char #xC0E8 ?샨) ; KS0-C-3C22
(ucs-set-char #xC0EC ?샬) ; KS0-C-3C23
(ucs-set-char #xC0F4 ?샴) ; KS0-C-3C24
(ucs-set-char #xC0F5 ?샵) ; KS0-C-3C25
(ucs-set-char #xC0F7 ?샷) ; KS0-C-3C26
(ucs-set-char #xC0F9 ?샹) ; KS0-C-3C27
(ucs-set-char #xC100 ?섀) ; KS0-C-3C28
(ucs-set-char #xC104 ?섄) ; KS0-C-3C29
(ucs-set-char #xC108 ?섈) ; KS0-C-3C2A
(ucs-set-char #xC110 ?섐) ; KS0-C-3C2B
(ucs-set-char #xC115 ?섕) ; KS0-C-3C2C
(ucs-set-char #xC11C ?서) ; KS0-C-3C2D
(ucs-set-char #xC11D ?석) ; KS0-C-3C2E
(ucs-set-char #xC11E ?섞) ; KS0-C-3C2F
(ucs-set-char #xC11F ?섟) ; KS0-C-3C30
(ucs-set-char #xC120 ?선) ; KS0-C-3C31
(ucs-set-char #xC123 ?섣) ; KS0-C-3C32
(ucs-set-char #xC124 ?설) ; KS0-C-3C33
(ucs-set-char #xC126 ?섦) ; KS0-C-3C34
(ucs-set-char #xC127 ?섧) ; KS0-C-3C35
(ucs-set-char #xC12C ?섬) ; KS0-C-3C36
(ucs-set-char #xC12D ?섭) ; KS0-C-3C37
(ucs-set-char #xC12F ?섯) ; KS0-C-3C38
(ucs-set-char #xC130 ?섰) ; KS0-C-3C39
(ucs-set-char #xC131 ?성) ; KS0-C-3C3A
(ucs-set-char #xC136 ?섶) ; KS0-C-3C3B
(ucs-set-char #xC138 ?세) ; KS0-C-3C3C
(ucs-set-char #xC139 ?섹) ; KS0-C-3C3D
(ucs-set-char #xC13C ?센) ; KS0-C-3C3E
(ucs-set-char #xC140 ?셀) ; KS0-C-3C3F
(ucs-set-char #xC148 ?셈) ; KS0-C-3C40
(ucs-set-char #xC149 ?셉) ; KS0-C-3C41
(ucs-set-char #xC14B ?셋) ; KS0-C-3C42
(ucs-set-char #xC14C ?셌) ; KS0-C-3C43
(ucs-set-char #xC14D ?셍) ; KS0-C-3C44
(ucs-set-char #xC154 ?셔) ; KS0-C-3C45
(ucs-set-char #xC155 ?셕) ; KS0-C-3C46
(ucs-set-char #xC158 ?션) ; KS0-C-3C47
(ucs-set-char #xC15C ?셜) ; KS0-C-3C48
(ucs-set-char #xC164 ?셤) ; KS0-C-3C49
(ucs-set-char #xC165 ?셥) ; KS0-C-3C4A
(ucs-set-char #xC167 ?셧) ; KS0-C-3C4B
(ucs-set-char #xC168 ?셨) ; KS0-C-3C4C
(ucs-set-char #xC169 ?셩) ; KS0-C-3C4D
(ucs-set-char #xC170 ?셰) ; KS0-C-3C4E
(ucs-set-char #xC174 ?셴) ; KS0-C-3C4F
(ucs-set-char #xC178 ?셸) ; KS0-C-3C50
(ucs-set-char #xC185 ?솅) ; KS0-C-3C51
(ucs-set-char #xC18C ?소) ; KS0-C-3C52
(ucs-set-char #xC18D ?속) ; KS0-C-3C53
(ucs-set-char #xC18E ?솎) ; KS0-C-3C54
(ucs-set-char #xC190 ?손) ; KS0-C-3C55
(ucs-set-char #xC194 ?솔) ; KS0-C-3C56
(ucs-set-char #xC196 ?솖) ; KS0-C-3C57
(ucs-set-char #xC19C ?솜) ; KS0-C-3C58
(ucs-set-char #xC19D ?솝) ; KS0-C-3C59
(ucs-set-char #xC19F ?솟) ; KS0-C-3C5A
(ucs-set-char #xC1A1 ?송) ; KS0-C-3C5B
(ucs-set-char #xC1A5 ?솥) ; KS0-C-3C5C
(ucs-set-char #xC1A8 ?솨) ; KS0-C-3C5D
(ucs-set-char #xC1A9 ?솩) ; KS0-C-3C5E
(ucs-set-char #xC1AC ?솬) ; KS0-C-3C5F
(ucs-set-char #xC1B0 ?솰) ; KS0-C-3C60
(ucs-set-char #xC1BD ?솽) ; KS0-C-3C61
(ucs-set-char #xC1C4 ?쇄) ; KS0-C-3C62
(ucs-set-char #xC1C8 ?쇈) ; KS0-C-3C63
(ucs-set-char #xC1CC ?쇌) ; KS0-C-3C64
(ucs-set-char #xC1D4 ?쇔) ; KS0-C-3C65
(ucs-set-char #xC1D7 ?쇗) ; KS0-C-3C66
(ucs-set-char #xC1D8 ?쇘) ; KS0-C-3C67
(ucs-set-char #xC1E0 ?쇠) ; KS0-C-3C68
(ucs-set-char #xC1E4 ?쇤) ; KS0-C-3C69
(ucs-set-char #xC1E8 ?쇨) ; KS0-C-3C6A
(ucs-set-char #xC1F0 ?쇰) ; KS0-C-3C6B
(ucs-set-char #xC1F1 ?쇱) ; KS0-C-3C6C
(ucs-set-char #xC1F3 ?쇳) ; KS0-C-3C6D
(ucs-set-char #xC1FC ?쇼) ; KS0-C-3C6E
(ucs-set-char #xC1FD ?쇽) ; KS0-C-3C6F
(ucs-set-char #xC200 ?숀) ; KS0-C-3C70
(ucs-set-char #xC204 ?숄) ; KS0-C-3C71
(ucs-set-char #xC20C ?숌) ; KS0-C-3C72
(ucs-set-char #xC20D ?숍) ; KS0-C-3C73
(ucs-set-char #xC20F ?숏) ; KS0-C-3C74
(ucs-set-char #xC211 ?숑) ; KS0-C-3C75
(ucs-set-char #xC218 ?수) ; KS0-C-3C76
(ucs-set-char #xC219 ?숙) ; KS0-C-3C77
(ucs-set-char #xC21C ?순) ; KS0-C-3C78
(ucs-set-char #xC21F ?숟) ; KS0-C-3C79
(ucs-set-char #xC220 ?술) ; KS0-C-3C7A
(ucs-set-char #xC228 ?숨) ; KS0-C-3C7B
(ucs-set-char #xC229 ?숩) ; KS0-C-3C7C
(ucs-set-char #xC22B ?숫) ; KS0-C-3C7D
(ucs-set-char #xC22D ?숭) ; KS0-C-3C7E
(ucs-set-char #xC22F ?숯) ; KS0-C-3D21
(ucs-set-char #xC231 ?숱) ; KS0-C-3D22
(ucs-set-char #xC232 ?숲) ; KS0-C-3D23
(ucs-set-char #xC234 ?숴) ; KS0-C-3D24
(ucs-set-char #xC248 ?쉈) ; KS0-C-3D25
(ucs-set-char #xC250 ?쉐) ; KS0-C-3D26
(ucs-set-char #xC251 ?쉑) ; KS0-C-3D27
(ucs-set-char #xC254 ?쉔) ; KS0-C-3D28
(ucs-set-char #xC258 ?쉘) ; KS0-C-3D29
(ucs-set-char #xC260 ?쉠) ; KS0-C-3D2A
(ucs-set-char #xC265 ?쉥) ; KS0-C-3D2B
(ucs-set-char #xC26C ?쉬) ; KS0-C-3D2C
(ucs-set-char #xC26D ?쉭) ; KS0-C-3D2D
(ucs-set-char #xC270 ?쉰) ; KS0-C-3D2E
(ucs-set-char #xC274 ?쉴) ; KS0-C-3D2F
(ucs-set-char #xC27C ?쉼) ; KS0-C-3D30
(ucs-set-char #xC27D ?쉽) ; KS0-C-3D31
(ucs-set-char #xC27F ?쉿) ; KS0-C-3D32
(ucs-set-char #xC281 ?슁) ; KS0-C-3D33
(ucs-set-char #xC288 ?슈) ; KS0-C-3D34
(ucs-set-char #xC289 ?슉) ; KS0-C-3D35
(ucs-set-char #xC290 ?슐) ; KS0-C-3D36
(ucs-set-char #xC298 ?슘) ; KS0-C-3D37
(ucs-set-char #xC29B ?슛) ; KS0-C-3D38
(ucs-set-char #xC29D ?슝) ; KS0-C-3D39
(ucs-set-char #xC2A4 ?스) ; KS0-C-3D3A
(ucs-set-char #xC2A5 ?슥) ; KS0-C-3D3B
(ucs-set-char #xC2A8 ?슨) ; KS0-C-3D3C
(ucs-set-char #xC2AC ?슬) ; KS0-C-3D3D
(ucs-set-char #xC2AD ?슭) ; KS0-C-3D3E
(ucs-set-char #xC2B4 ?슴) ; KS0-C-3D3F
(ucs-set-char #xC2B5 ?습) ; KS0-C-3D40
(ucs-set-char #xC2B7 ?슷) ; KS0-C-3D41
(ucs-set-char #xC2B9 ?승) ; KS0-C-3D42
(ucs-set-char #xC2DC ?시) ; KS0-C-3D43
(ucs-set-char #xC2DD ?식) ; KS0-C-3D44
(ucs-set-char #xC2E0 ?신) ; KS0-C-3D45
(ucs-set-char #xC2E3 ?싣) ; KS0-C-3D46
(ucs-set-char #xC2E4 ?실) ; KS0-C-3D47
(ucs-set-char #xC2EB ?싫) ; KS0-C-3D48
(ucs-set-char #xC2EC ?심) ; KS0-C-3D49
(ucs-set-char #xC2ED ?십) ; KS0-C-3D4A
(ucs-set-char #xC2EF ?싯) ; KS0-C-3D4B
(ucs-set-char #xC2F1 ?싱) ; KS0-C-3D4C
(ucs-set-char #xC2F6 ?싶) ; KS0-C-3D4D
(ucs-set-char #xC2F8 ?싸) ; KS0-C-3D4E
(ucs-set-char #xC2F9 ?싹) ; KS0-C-3D4F
(ucs-set-char #xC2FB ?싻) ; KS0-C-3D50
(ucs-set-char #xC2FC ?싼) ; KS0-C-3D51
(ucs-set-char #xC300 ?쌀) ; KS0-C-3D52
(ucs-set-char #xC308 ?쌈) ; KS0-C-3D53
(ucs-set-char #xC309 ?쌉) ; KS0-C-3D54
(ucs-set-char #xC30C ?쌌) ; KS0-C-3D55
(ucs-set-char #xC30D ?쌍) ; KS0-C-3D56
(ucs-set-char #xC313 ?쌓) ; KS0-C-3D57
(ucs-set-char #xC314 ?쌔) ; KS0-C-3D58
(ucs-set-char #xC315 ?쌕) ; KS0-C-3D59
(ucs-set-char #xC318 ?쌘) ; KS0-C-3D5A
(ucs-set-char #xC31C ?쌜) ; KS0-C-3D5B
(ucs-set-char #xC324 ?쌤) ; KS0-C-3D5C
(ucs-set-char #xC325 ?쌥) ; KS0-C-3D5D
(ucs-set-char #xC328 ?쌨) ; KS0-C-3D5E
(ucs-set-char #xC329 ?쌩) ; KS0-C-3D5F
(ucs-set-char #xC345 ?썅) ; KS0-C-3D60
(ucs-set-char #xC368 ?써) ; KS0-C-3D61
(ucs-set-char #xC369 ?썩) ; KS0-C-3D62
(ucs-set-char #xC36C ?썬) ; KS0-C-3D63
(ucs-set-char #xC370 ?썰) ; KS0-C-3D64
(ucs-set-char #xC372 ?썲) ; KS0-C-3D65
(ucs-set-char #xC378 ?썸) ; KS0-C-3D66
(ucs-set-char #xC379 ?썹) ; KS0-C-3D67
(ucs-set-char #xC37C ?썼) ; KS0-C-3D68
(ucs-set-char #xC37D ?썽) ; KS0-C-3D69
(ucs-set-char #xC384 ?쎄) ; KS0-C-3D6A
(ucs-set-char #xC388 ?쎈) ; KS0-C-3D6B
(ucs-set-char #xC38C ?쎌) ; KS0-C-3D6C
(ucs-set-char #xC3C0 ?쏀) ; KS0-C-3D6D
(ucs-set-char #xC3D8 ?쏘) ; KS0-C-3D6E
(ucs-set-char #xC3D9 ?쏙) ; KS0-C-3D6F
(ucs-set-char #xC3DC ?쏜) ; KS0-C-3D70
(ucs-set-char #xC3DF ?쏟) ; KS0-C-3D71
(ucs-set-char #xC3E0 ?쏠) ; KS0-C-3D72
(ucs-set-char #xC3E2 ?쏢) ; KS0-C-3D73
(ucs-set-char #xC3E8 ?쏨) ; KS0-C-3D74
(ucs-set-char #xC3E9 ?쏩) ; KS0-C-3D75
(ucs-set-char #xC3ED ?쏭) ; KS0-C-3D76
(ucs-set-char #xC3F4 ?쏴) ; KS0-C-3D77
(ucs-set-char #xC3F5 ?쏵) ; KS0-C-3D78
(ucs-set-char #xC3F8 ?쏸) ; KS0-C-3D79
(ucs-set-char #xC408 ?쐈) ; KS0-C-3D7A
(ucs-set-char #xC410 ?쐐) ; KS0-C-3D7B
(ucs-set-char #xC424 ?쐤) ; KS0-C-3D7C
(ucs-set-char #xC42C ?쐬) ; KS0-C-3D7D
(ucs-set-char #xC430 ?쐰) ; KS0-C-3D7E
(ucs-set-char #xC434 ?쐴) ; KS0-C-3E21
(ucs-set-char #xC43C ?쐼) ; KS0-C-3E22
(ucs-set-char #xC43D ?쐽) ; KS0-C-3E23
(ucs-set-char #xC448 ?쑈) ; KS0-C-3E24
(ucs-set-char #xC464 ?쑤) ; KS0-C-3E25
(ucs-set-char #xC465 ?쑥) ; KS0-C-3E26
(ucs-set-char #xC468 ?쑨) ; KS0-C-3E27
(ucs-set-char #xC46C ?쑬) ; KS0-C-3E28
(ucs-set-char #xC474 ?쑴) ; KS0-C-3E29
(ucs-set-char #xC475 ?쑵) ; KS0-C-3E2A
(ucs-set-char #xC479 ?쑹) ; KS0-C-3E2B
(ucs-set-char #xC480 ?쒀) ; KS0-C-3E2C
(ucs-set-char #xC494 ?쒔) ; KS0-C-3E2D
(ucs-set-char #xC49C ?쒜) ; KS0-C-3E2E
(ucs-set-char #xC4B8 ?쒸) ; KS0-C-3E2F
(ucs-set-char #xC4BC ?쒼) ; KS0-C-3E30
(ucs-set-char #xC4E9 ?쓩) ; KS0-C-3E31
(ucs-set-char #xC4F0 ?쓰) ; KS0-C-3E32
(ucs-set-char #xC4F1 ?쓱) ; KS0-C-3E33
(ucs-set-char #xC4F4 ?쓴) ; KS0-C-3E34
(ucs-set-char #xC4F8 ?쓸) ; KS0-C-3E35
(ucs-set-char #xC4FA ?쓺) ; KS0-C-3E36
(ucs-set-char #xC4FF ?쓿) ; KS0-C-3E37
(ucs-set-char #xC500 ?씀) ; KS0-C-3E38
(ucs-set-char #xC501 ?씁) ; KS0-C-3E39
(ucs-set-char #xC50C ?씌) ; KS0-C-3E3A
(ucs-set-char #xC510 ?씐) ; KS0-C-3E3B
(ucs-set-char #xC514 ?씔) ; KS0-C-3E3C
(ucs-set-char #xC51C ?씜) ; KS0-C-3E3D
(ucs-set-char #xC528 ?씨) ; KS0-C-3E3E
(ucs-set-char #xC529 ?씩) ; KS0-C-3E3F
(ucs-set-char #xC52C ?씬) ; KS0-C-3E40
(ucs-set-char #xC530 ?씰) ; KS0-C-3E41
(ucs-set-char #xC538 ?씸) ; KS0-C-3E42
(ucs-set-char #xC539 ?씹) ; KS0-C-3E43
(ucs-set-char #xC53B ?씻) ; KS0-C-3E44
(ucs-set-char #xC53D ?씽) ; KS0-C-3E45
(ucs-set-char #xC544 ?아) ; KS0-C-3E46
(ucs-set-char #xC545 ?악) ; KS0-C-3E47
(ucs-set-char #xC548 ?안) ; KS0-C-3E48
(ucs-set-char #xC549 ?앉) ; KS0-C-3E49
(ucs-set-char #xC54A ?않) ; KS0-C-3E4A
(ucs-set-char #xC54C ?알) ; KS0-C-3E4B
(ucs-set-char #xC54D ?앍) ; KS0-C-3E4C
(ucs-set-char #xC54E ?앎) ; KS0-C-3E4D
(ucs-set-char #xC553 ?앓) ; KS0-C-3E4E
(ucs-set-char #xC554 ?암) ; KS0-C-3E4F
(ucs-set-char #xC555 ?압) ; KS0-C-3E50
(ucs-set-char #xC557 ?앗) ; KS0-C-3E51
(ucs-set-char #xC558 ?았) ; KS0-C-3E52
(ucs-set-char #xC559 ?앙) ; KS0-C-3E53
(ucs-set-char #xC55D ?앝) ; KS0-C-3E54
(ucs-set-char #xC55E ?앞) ; KS0-C-3E55
(ucs-set-char #xC560 ?애) ; KS0-C-3E56
(ucs-set-char #xC561 ?액) ; KS0-C-3E57
(ucs-set-char #xC564 ?앤) ; KS0-C-3E58
(ucs-set-char #xC568 ?앨) ; KS0-C-3E59
(ucs-set-char #xC570 ?앰) ; KS0-C-3E5A
(ucs-set-char #xC571 ?앱) ; KS0-C-3E5B
(ucs-set-char #xC573 ?앳) ; KS0-C-3E5C
(ucs-set-char #xC574 ?앴) ; KS0-C-3E5D
(ucs-set-char #xC575 ?앵) ; KS0-C-3E5E
(ucs-set-char #xC57C ?야) ; KS0-C-3E5F
(ucs-set-char #xC57D ?약) ; KS0-C-3E60
(ucs-set-char #xC580 ?얀) ; KS0-C-3E61
(ucs-set-char #xC584 ?얄) ; KS0-C-3E62
(ucs-set-char #xC587 ?얇) ; KS0-C-3E63
(ucs-set-char #xC58C ?얌) ; KS0-C-3E64
(ucs-set-char #xC58D ?얍) ; KS0-C-3E65
(ucs-set-char #xC58F ?얏) ; KS0-C-3E66
(ucs-set-char #xC591 ?양) ; KS0-C-3E67
(ucs-set-char #xC595 ?얕) ; KS0-C-3E68
(ucs-set-char #xC597 ?얗) ; KS0-C-3E69
(ucs-set-char #xC598 ?얘) ; KS0-C-3E6A
(ucs-set-char #xC59C ?얜) ; KS0-C-3E6B
(ucs-set-char #xC5A0 ?얠) ; KS0-C-3E6C
(ucs-set-char #xC5A9 ?얩) ; KS0-C-3E6D
(ucs-set-char #xC5B4 ?어) ; KS0-C-3E6E
(ucs-set-char #xC5B5 ?억) ; KS0-C-3E6F
(ucs-set-char #xC5B8 ?언) ; KS0-C-3E70
(ucs-set-char #xC5B9 ?얹) ; KS0-C-3E71
(ucs-set-char #xC5BB ?얻) ; KS0-C-3E72
(ucs-set-char #xC5BC ?얼) ; KS0-C-3E73
(ucs-set-char #xC5BD ?얽) ; KS0-C-3E74
(ucs-set-char #xC5BE ?얾) ; KS0-C-3E75
(ucs-set-char #xC5C4 ?엄) ; KS0-C-3E76
(ucs-set-char #xC5C5 ?업) ; KS0-C-3E77
(ucs-set-char #xC5C6 ?없) ; KS0-C-3E78
(ucs-set-char #xC5C7 ?엇) ; KS0-C-3E79
(ucs-set-char #xC5C8 ?었) ; KS0-C-3E7A
(ucs-set-char #xC5C9 ?엉) ; KS0-C-3E7B
(ucs-set-char #xC5CA ?엊) ; KS0-C-3E7C
(ucs-set-char #xC5CC ?엌) ; KS0-C-3E7D
(ucs-set-char #xC5CE ?엎) ; KS0-C-3E7E
(ucs-set-char #xC5D0 ?에) ; KS0-C-3F21
(ucs-set-char #xC5D1 ?엑) ; KS0-C-3F22
(ucs-set-char #xC5D4 ?엔) ; KS0-C-3F23
(ucs-set-char #xC5D8 ?엘) ; KS0-C-3F24
(ucs-set-char #xC5E0 ?엠) ; KS0-C-3F25
(ucs-set-char #xC5E1 ?엡) ; KS0-C-3F26
(ucs-set-char #xC5E3 ?엣) ; KS0-C-3F27
(ucs-set-char #xC5E5 ?엥) ; KS0-C-3F28
(ucs-set-char #xC5EC ?여) ; KS0-C-3F29
(ucs-set-char #xC5ED ?역) ; KS0-C-3F2A
(ucs-set-char #xC5EE ?엮) ; KS0-C-3F2B
(ucs-set-char #xC5F0 ?연) ; KS0-C-3F2C
(ucs-set-char #xC5F4 ?열) ; KS0-C-3F2D
(ucs-set-char #xC5F6 ?엶) ; KS0-C-3F2E
(ucs-set-char #xC5F7 ?엷) ; KS0-C-3F2F
(ucs-set-char #xC5FC ?염) ; KS0-C-3F30
(ucs-set-char #xC5FD ?엽) ; KS0-C-3F31
(ucs-set-char #xC5FE ?엾) ; KS0-C-3F32
(ucs-set-char #xC5FF ?엿) ; KS0-C-3F33
(ucs-set-char #xC600 ?였) ; KS0-C-3F34
(ucs-set-char #xC601 ?영) ; KS0-C-3F35
(ucs-set-char #xC605 ?옅) ; KS0-C-3F36
(ucs-set-char #xC606 ?옆) ; KS0-C-3F37
(ucs-set-char #xC607 ?옇) ; KS0-C-3F38
(ucs-set-char #xC608 ?예) ; KS0-C-3F39
(ucs-set-char #xC60C ?옌) ; KS0-C-3F3A
(ucs-set-char #xC610 ?옐) ; KS0-C-3F3B
(ucs-set-char #xC618 ?옘) ; KS0-C-3F3C
(ucs-set-char #xC619 ?옙) ; KS0-C-3F3D
(ucs-set-char #xC61B ?옛) ; KS0-C-3F3E
(ucs-set-char #xC61C ?옜) ; KS0-C-3F3F
(ucs-set-char #xC624 ?오) ; KS0-C-3F40
(ucs-set-char #xC625 ?옥) ; KS0-C-3F41
(ucs-set-char #xC628 ?온) ; KS0-C-3F42
(ucs-set-char #xC62C ?올) ; KS0-C-3F43
(ucs-set-char #xC62D ?옭) ; KS0-C-3F44
(ucs-set-char #xC62E ?옮) ; KS0-C-3F45
(ucs-set-char #xC630 ?옰) ; KS0-C-3F46
(ucs-set-char #xC633 ?옳) ; KS0-C-3F47
(ucs-set-char #xC634 ?옴) ; KS0-C-3F48
(ucs-set-char #xC635 ?옵) ; KS0-C-3F49
(ucs-set-char #xC637 ?옷) ; KS0-C-3F4A
(ucs-set-char #xC639 ?옹) ; KS0-C-3F4B
(ucs-set-char #xC63B ?옻) ; KS0-C-3F4C
(ucs-set-char #xC640 ?와) ; KS0-C-3F4D
(ucs-set-char #xC641 ?왁) ; KS0-C-3F4E
(ucs-set-char #xC644 ?완) ; KS0-C-3F4F
(ucs-set-char #xC648 ?왈) ; KS0-C-3F50
(ucs-set-char #xC650 ?왐) ; KS0-C-3F51
(ucs-set-char #xC651 ?왑) ; KS0-C-3F52
(ucs-set-char #xC653 ?왓) ; KS0-C-3F53
(ucs-set-char #xC654 ?왔) ; KS0-C-3F54
(ucs-set-char #xC655 ?왕) ; KS0-C-3F55
(ucs-set-char #xC65C ?왜) ; KS0-C-3F56
(ucs-set-char #xC65D ?왝) ; KS0-C-3F57
(ucs-set-char #xC660 ?왠) ; KS0-C-3F58
(ucs-set-char #xC66C ?왬) ; KS0-C-3F59
(ucs-set-char #xC66F ?왯) ; KS0-C-3F5A
(ucs-set-char #xC671 ?왱) ; KS0-C-3F5B
(ucs-set-char #xC678 ?외) ; KS0-C-3F5C
(ucs-set-char #xC679 ?왹) ; KS0-C-3F5D
(ucs-set-char #xC67C ?왼) ; KS0-C-3F5E
(ucs-set-char #xC680 ?욀) ; KS0-C-3F5F
(ucs-set-char #xC688 ?욈) ; KS0-C-3F60
(ucs-set-char #xC689 ?욉) ; KS0-C-3F61
(ucs-set-char #xC68B ?욋) ; KS0-C-3F62
(ucs-set-char #xC68D ?욍) ; KS0-C-3F63
(ucs-set-char #xC694 ?요) ; KS0-C-3F64
(ucs-set-char #xC695 ?욕) ; KS0-C-3F65
(ucs-set-char #xC698 ?욘) ; KS0-C-3F66
(ucs-set-char #xC69C ?욜) ; KS0-C-3F67
(ucs-set-char #xC6A4 ?욤) ; KS0-C-3F68
(ucs-set-char #xC6A5 ?욥) ; KS0-C-3F69
(ucs-set-char #xC6A7 ?욧) ; KS0-C-3F6A
(ucs-set-char #xC6A9 ?용) ; KS0-C-3F6B
(ucs-set-char #xC6B0 ?우) ; KS0-C-3F6C
(ucs-set-char #xC6B1 ?욱) ; KS0-C-3F6D
(ucs-set-char #xC6B4 ?운) ; KS0-C-3F6E
(ucs-set-char #xC6B8 ?울) ; KS0-C-3F6F
(ucs-set-char #xC6B9 ?욹) ; KS0-C-3F70
(ucs-set-char #xC6BA ?욺) ; KS0-C-3F71
(ucs-set-char #xC6C0 ?움) ; KS0-C-3F72
(ucs-set-char #xC6C1 ?웁) ; KS0-C-3F73
(ucs-set-char #xC6C3 ?웃) ; KS0-C-3F74
(ucs-set-char #xC6C5 ?웅) ; KS0-C-3F75
(ucs-set-char #xC6CC ?워) ; KS0-C-3F76
(ucs-set-char #xC6CD ?웍) ; KS0-C-3F77
(ucs-set-char #xC6D0 ?원) ; KS0-C-3F78
(ucs-set-char #xC6D4 ?월) ; KS0-C-3F79
(ucs-set-char #xC6DC ?웜) ; KS0-C-3F7A
(ucs-set-char #xC6DD ?웝) ; KS0-C-3F7B
(ucs-set-char #xC6E0 ?웠) ; KS0-C-3F7C
(ucs-set-char #xC6E1 ?웡) ; KS0-C-3F7D
(ucs-set-char #xC6E8 ?웨) ; KS0-C-3F7E
(ucs-set-char #xC6E9 ?웩) ; KS0-C-4021
(ucs-set-char #xC6EC ?웬) ; KS0-C-4022
(ucs-set-char #xC6F0 ?웰) ; KS0-C-4023
(ucs-set-char #xC6F8 ?웸) ; KS0-C-4024
(ucs-set-char #xC6F9 ?웹) ; KS0-C-4025
(ucs-set-char #xC6FD ?웽) ; KS0-C-4026
(ucs-set-char #xC704 ?위) ; KS0-C-4027
(ucs-set-char #xC705 ?윅) ; KS0-C-4028
(ucs-set-char #xC708 ?윈) ; KS0-C-4029
(ucs-set-char #xC70C ?윌) ; KS0-C-402A
(ucs-set-char #xC714 ?윔) ; KS0-C-402B
(ucs-set-char #xC715 ?윕) ; KS0-C-402C
(ucs-set-char #xC717 ?윗) ; KS0-C-402D
(ucs-set-char #xC719 ?윙) ; KS0-C-402E
(ucs-set-char #xC720 ?유) ; KS0-C-402F
(ucs-set-char #xC721 ?육) ; KS0-C-4030
(ucs-set-char #xC724 ?윤) ; KS0-C-4031
(ucs-set-char #xC728 ?율) ; KS0-C-4032
(ucs-set-char #xC730 ?윰) ; KS0-C-4033
(ucs-set-char #xC731 ?윱) ; KS0-C-4034
(ucs-set-char #xC733 ?윳) ; KS0-C-4035
(ucs-set-char #xC735 ?융) ; KS0-C-4036
(ucs-set-char #xC737 ?윷) ; KS0-C-4037
(ucs-set-char #xC73C ?으) ; KS0-C-4038
(ucs-set-char #xC73D ?윽) ; KS0-C-4039
(ucs-set-char #xC740 ?은) ; KS0-C-403A
(ucs-set-char #xC744 ?을) ; KS0-C-403B
(ucs-set-char #xC74A ?읊) ; KS0-C-403C
(ucs-set-char #xC74C ?음) ; KS0-C-403D
(ucs-set-char #xC74D ?읍) ; KS0-C-403E
(ucs-set-char #xC74F ?읏) ; KS0-C-403F
(ucs-set-char #xC751 ?응) ; KS0-C-4040
(ucs-set-char #xC752 ?읒) ; KS0-C-4041
(ucs-set-char #xC753 ?읓) ; KS0-C-4042
(ucs-set-char #xC754 ?읔) ; KS0-C-4043
(ucs-set-char #xC755 ?읕) ; KS0-C-4044
(ucs-set-char #xC756 ?읖) ; KS0-C-4045
(ucs-set-char #xC757 ?읗) ; KS0-C-4046
(ucs-set-char #xC758 ?의) ; KS0-C-4047
(ucs-set-char #xC75C ?읜) ; KS0-C-4048
(ucs-set-char #xC760 ?읠) ; KS0-C-4049
(ucs-set-char #xC768 ?읨) ; KS0-C-404A
(ucs-set-char #xC76B ?읫) ; KS0-C-404B
(ucs-set-char #xC774 ?이) ; KS0-C-404C
(ucs-set-char #xC775 ?익) ; KS0-C-404D
(ucs-set-char #xC778 ?인) ; KS0-C-404E
(ucs-set-char #xC77C ?일) ; KS0-C-404F
(ucs-set-char #xC77D ?읽) ; KS0-C-4050
(ucs-set-char #xC77E ?읾) ; KS0-C-4051
(ucs-set-char #xC783 ?잃) ; KS0-C-4052
(ucs-set-char #xC784 ?임) ; KS0-C-4053
(ucs-set-char #xC785 ?입) ; KS0-C-4054
(ucs-set-char #xC787 ?잇) ; KS0-C-4055
(ucs-set-char #xC788 ?있) ; KS0-C-4056
(ucs-set-char #xC789 ?잉) ; KS0-C-4057
(ucs-set-char #xC78A ?잊) ; KS0-C-4058
(ucs-set-char #xC78E ?잎) ; KS0-C-4059
(ucs-set-char #xC790 ?자) ; KS0-C-405A
(ucs-set-char #xC791 ?작) ; KS0-C-405B
(ucs-set-char #xC794 ?잔) ; KS0-C-405C
(ucs-set-char #xC796 ?잖) ; KS0-C-405D
(ucs-set-char #xC797 ?잗) ; KS0-C-405E
(ucs-set-char #xC798 ?잘) ; KS0-C-405F
(ucs-set-char #xC79A ?잚) ; KS0-C-4060
(ucs-set-char #xC7A0 ?잠) ; KS0-C-4061
(ucs-set-char #xC7A1 ?잡) ; KS0-C-4062
(ucs-set-char #xC7A3 ?잣) ; KS0-C-4063
(ucs-set-char #xC7A4 ?잤) ; KS0-C-4064
(ucs-set-char #xC7A5 ?장) ; KS0-C-4065
(ucs-set-char #xC7A6 ?잦) ; KS0-C-4066
(ucs-set-char #xC7AC ?재) ; KS0-C-4067
(ucs-set-char #xC7AD ?잭) ; KS0-C-4068
(ucs-set-char #xC7B0 ?잰) ; KS0-C-4069
(ucs-set-char #xC7B4 ?잴) ; KS0-C-406A
(ucs-set-char #xC7BC ?잼) ; KS0-C-406B
(ucs-set-char #xC7BD ?잽) ; KS0-C-406C
(ucs-set-char #xC7BF ?잿) ; KS0-C-406D
(ucs-set-char #xC7C0 ?쟀) ; KS0-C-406E
(ucs-set-char #xC7C1 ?쟁) ; KS0-C-406F
(ucs-set-char #xC7C8 ?쟈) ; KS0-C-4070
(ucs-set-char #xC7C9 ?쟉) ; KS0-C-4071
(ucs-set-char #xC7CC ?쟌) ; KS0-C-4072
(ucs-set-char #xC7CE ?쟎) ; KS0-C-4073
(ucs-set-char #xC7D0 ?쟐) ; KS0-C-4074
(ucs-set-char #xC7D8 ?쟘) ; KS0-C-4075
(ucs-set-char #xC7DD ?쟝) ; KS0-C-4076
(ucs-set-char #xC7E4 ?쟤) ; KS0-C-4077
(ucs-set-char #xC7E8 ?쟨) ; KS0-C-4078
(ucs-set-char #xC7EC ?쟬) ; KS0-C-4079
(ucs-set-char #xC800 ?저) ; KS0-C-407A
(ucs-set-char #xC801 ?적) ; KS0-C-407B
(ucs-set-char #xC804 ?전) ; KS0-C-407C
(ucs-set-char #xC808 ?절) ; KS0-C-407D
(ucs-set-char #xC80A ?젊) ; KS0-C-407E
(ucs-set-char #xC810 ?점) ; KS0-C-4121
(ucs-set-char #xC811 ?접) ; KS0-C-4122
(ucs-set-char #xC813 ?젓) ; KS0-C-4123
(ucs-set-char #xC815 ?정) ; KS0-C-4124
(ucs-set-char #xC816 ?젖) ; KS0-C-4125
(ucs-set-char #xC81C ?제) ; KS0-C-4126
(ucs-set-char #xC81D ?젝) ; KS0-C-4127
(ucs-set-char #xC820 ?젠) ; KS0-C-4128
(ucs-set-char #xC824 ?젤) ; KS0-C-4129
(ucs-set-char #xC82C ?젬) ; KS0-C-412A
(ucs-set-char #xC82D ?젭) ; KS0-C-412B
(ucs-set-char #xC82F ?젯) ; KS0-C-412C
(ucs-set-char #xC831 ?젱) ; KS0-C-412D
(ucs-set-char #xC838 ?져) ; KS0-C-412E
(ucs-set-char #xC83C ?젼) ; KS0-C-412F
(ucs-set-char #xC840 ?졀) ; KS0-C-4130
(ucs-set-char #xC848 ?졈) ; KS0-C-4131
(ucs-set-char #xC849 ?졉) ; KS0-C-4132
(ucs-set-char #xC84C ?졌) ; KS0-C-4133
(ucs-set-char #xC84D ?졍) ; KS0-C-4134
(ucs-set-char #xC854 ?졔) ; KS0-C-4135
(ucs-set-char #xC870 ?조) ; KS0-C-4136
(ucs-set-char #xC871 ?족) ; KS0-C-4137
(ucs-set-char #xC874 ?존) ; KS0-C-4138
(ucs-set-char #xC878 ?졸) ; KS0-C-4139
(ucs-set-char #xC87A ?졺) ; KS0-C-413A
(ucs-set-char #xC880 ?좀) ; KS0-C-413B
(ucs-set-char #xC881 ?좁) ; KS0-C-413C
(ucs-set-char #xC883 ?좃) ; KS0-C-413D
(ucs-set-char #xC885 ?종) ; KS0-C-413E
(ucs-set-char #xC886 ?좆) ; KS0-C-413F
(ucs-set-char #xC887 ?좇) ; KS0-C-4140
(ucs-set-char #xC88B ?좋) ; KS0-C-4141
(ucs-set-char #xC88C ?좌) ; KS0-C-4142
(ucs-set-char #xC88D ?좍) ; KS0-C-4143
(ucs-set-char #xC894 ?좔) ; KS0-C-4144
(ucs-set-char #xC89D ?좝) ; KS0-C-4145
(ucs-set-char #xC89F ?좟) ; KS0-C-4146
(ucs-set-char #xC8A1 ?좡) ; KS0-C-4147
(ucs-set-char #xC8A8 ?좨) ; KS0-C-4148
(ucs-set-char #xC8BC ?좼) ; KS0-C-4149
(ucs-set-char #xC8BD ?좽) ; KS0-C-414A
(ucs-set-char #xC8C4 ?죄) ; KS0-C-414B
(ucs-set-char #xC8C8 ?죈) ; KS0-C-414C
(ucs-set-char #xC8CC ?죌) ; KS0-C-414D
(ucs-set-char #xC8D4 ?죔) ; KS0-C-414E
(ucs-set-char #xC8D5 ?죕) ; KS0-C-414F
(ucs-set-char #xC8D7 ?죗) ; KS0-C-4150
(ucs-set-char #xC8D9 ?죙) ; KS0-C-4151
(ucs-set-char #xC8E0 ?죠) ; KS0-C-4152
(ucs-set-char #xC8E1 ?죡) ; KS0-C-4153
(ucs-set-char #xC8E4 ?죤) ; KS0-C-4154
(ucs-set-char #xC8F5 ?죵) ; KS0-C-4155
(ucs-set-char #xC8FC ?주) ; KS0-C-4156
(ucs-set-char #xC8FD ?죽) ; KS0-C-4157
(ucs-set-char #xC900 ?준) ; KS0-C-4158
(ucs-set-char #xC904 ?줄) ; KS0-C-4159
(ucs-set-char #xC905 ?줅) ; KS0-C-415A
(ucs-set-char #xC906 ?줆) ; KS0-C-415B
(ucs-set-char #xC90C ?줌) ; KS0-C-415C
(ucs-set-char #xC90D ?줍) ; KS0-C-415D
(ucs-set-char #xC90F ?줏) ; KS0-C-415E
(ucs-set-char #xC911 ?중) ; KS0-C-415F
(ucs-set-char #xC918 ?줘) ; KS0-C-4160
(ucs-set-char #xC92C ?줬) ; KS0-C-4161
(ucs-set-char #xC934 ?줴) ; KS0-C-4162
(ucs-set-char #xC950 ?쥐) ; KS0-C-4163
(ucs-set-char #xC951 ?쥑) ; KS0-C-4164
(ucs-set-char #xC954 ?쥔) ; KS0-C-4165
(ucs-set-char #xC958 ?쥘) ; KS0-C-4166
(ucs-set-char #xC960 ?쥠) ; KS0-C-4167
(ucs-set-char #xC961 ?쥡) ; KS0-C-4168
(ucs-set-char #xC963 ?쥣) ; KS0-C-4169
(ucs-set-char #xC96C ?쥬) ; KS0-C-416A
(ucs-set-char #xC970 ?쥰) ; KS0-C-416B
(ucs-set-char #xC974 ?쥴) ; KS0-C-416C
(ucs-set-char #xC97C ?쥼) ; KS0-C-416D
(ucs-set-char #xC988 ?즈) ; KS0-C-416E
(ucs-set-char #xC989 ?즉) ; KS0-C-416F
(ucs-set-char #xC98C ?즌) ; KS0-C-4170
(ucs-set-char #xC990 ?즐) ; KS0-C-4171
(ucs-set-char #xC998 ?즘) ; KS0-C-4172
(ucs-set-char #xC999 ?즙) ; KS0-C-4173
(ucs-set-char #xC99B ?즛) ; KS0-C-4174
(ucs-set-char #xC99D ?증) ; KS0-C-4175
(ucs-set-char #xC9C0 ?지) ; KS0-C-4176
(ucs-set-char #xC9C1 ?직) ; KS0-C-4177
(ucs-set-char #xC9C4 ?진) ; KS0-C-4178
(ucs-set-char #xC9C7 ?짇) ; KS0-C-4179
(ucs-set-char #xC9C8 ?질) ; KS0-C-417A
(ucs-set-char #xC9CA ?짊) ; KS0-C-417B
(ucs-set-char #xC9D0 ?짐) ; KS0-C-417C
(ucs-set-char #xC9D1 ?집) ; KS0-C-417D
(ucs-set-char #xC9D3 ?짓) ; KS0-C-417E
(ucs-set-char #xC9D5 ?징) ; KS0-C-4221
(ucs-set-char #xC9D6 ?짖) ; KS0-C-4222
(ucs-set-char #xC9D9 ?짙) ; KS0-C-4223
(ucs-set-char #xC9DA ?짚) ; KS0-C-4224
(ucs-set-char #xC9DC ?짜) ; KS0-C-4225
(ucs-set-char #xC9DD ?짝) ; KS0-C-4226
(ucs-set-char #xC9E0 ?짠) ; KS0-C-4227
(ucs-set-char #xC9E2 ?짢) ; KS0-C-4228
(ucs-set-char #xC9E4 ?짤) ; KS0-C-4229
(ucs-set-char #xC9E7 ?짧) ; KS0-C-422A
(ucs-set-char #xC9EC ?짬) ; KS0-C-422B
(ucs-set-char #xC9ED ?짭) ; KS0-C-422C
(ucs-set-char #xC9EF ?짯) ; KS0-C-422D
(ucs-set-char #xC9F0 ?짰) ; KS0-C-422E
(ucs-set-char #xC9F1 ?짱) ; KS0-C-422F
(ucs-set-char #xC9F8 ?째) ; KS0-C-4230
(ucs-set-char #xC9F9 ?짹) ; KS0-C-4231
(ucs-set-char #xC9FC ?짼) ; KS0-C-4232
(ucs-set-char #xCA00 ?쨀) ; KS0-C-4233
(ucs-set-char #xCA08 ?쨈) ; KS0-C-4234
(ucs-set-char #xCA09 ?쨉) ; KS0-C-4235
(ucs-set-char #xCA0B ?쨋) ; KS0-C-4236
(ucs-set-char #xCA0C ?쨌) ; KS0-C-4237
(ucs-set-char #xCA0D ?쨍) ; KS0-C-4238
(ucs-set-char #xCA14 ?쨔) ; KS0-C-4239
(ucs-set-char #xCA18 ?쨘) ; KS0-C-423A
(ucs-set-char #xCA29 ?쨩) ; KS0-C-423B
(ucs-set-char #xCA4C ?쩌) ; KS0-C-423C
(ucs-set-char #xCA4D ?쩍) ; KS0-C-423D
(ucs-set-char #xCA50 ?쩐) ; KS0-C-423E
(ucs-set-char #xCA54 ?쩔) ; KS0-C-423F
(ucs-set-char #xCA5C ?쩜) ; KS0-C-4240
(ucs-set-char #xCA5D ?쩝) ; KS0-C-4241
(ucs-set-char #xCA5F ?쩟) ; KS0-C-4242
(ucs-set-char #xCA60 ?쩠) ; KS0-C-4243
(ucs-set-char #xCA61 ?쩡) ; KS0-C-4244
(ucs-set-char #xCA68 ?쩨) ; KS0-C-4245
(ucs-set-char #xCA7D ?쩽) ; KS0-C-4246
(ucs-set-char #xCA84 ?쪄) ; KS0-C-4247
(ucs-set-char #xCA98 ?쪘) ; KS0-C-4248
(ucs-set-char #xCABC ?쪼) ; KS0-C-4249
(ucs-set-char #xCABD ?쪽) ; KS0-C-424A
(ucs-set-char #xCAC0 ?쫀) ; KS0-C-424B
(ucs-set-char #xCAC4 ?쫄) ; KS0-C-424C
(ucs-set-char #xCACC ?쫌) ; KS0-C-424D
(ucs-set-char #xCACD ?쫍) ; KS0-C-424E
(ucs-set-char #xCACF ?쫏) ; KS0-C-424F
(ucs-set-char #xCAD1 ?쫑) ; KS0-C-4250
(ucs-set-char #xCAD3 ?쫓) ; KS0-C-4251
(ucs-set-char #xCAD8 ?쫘) ; KS0-C-4252
(ucs-set-char #xCAD9 ?쫙) ; KS0-C-4253
(ucs-set-char #xCAE0 ?쫠) ; KS0-C-4254
(ucs-set-char #xCAEC ?쫬) ; KS0-C-4255
(ucs-set-char #xCAF4 ?쫴) ; KS0-C-4256
(ucs-set-char #xCB08 ?쬈) ; KS0-C-4257
(ucs-set-char #xCB10 ?쬐) ; KS0-C-4258
(ucs-set-char #xCB14 ?쬔) ; KS0-C-4259
(ucs-set-char #xCB18 ?쬘) ; KS0-C-425A
(ucs-set-char #xCB20 ?쬠) ; KS0-C-425B
(ucs-set-char #xCB21 ?쬡) ; KS0-C-425C
(ucs-set-char #xCB41 ?쭁) ; KS0-C-425D
(ucs-set-char #xCB48 ?쭈) ; KS0-C-425E
(ucs-set-char #xCB49 ?쭉) ; KS0-C-425F
(ucs-set-char #xCB4C ?쭌) ; KS0-C-4260
(ucs-set-char #xCB50 ?쭐) ; KS0-C-4261
(ucs-set-char #xCB58 ?쭘) ; KS0-C-4262
(ucs-set-char #xCB59 ?쭙) ; KS0-C-4263
(ucs-set-char #xCB5D ?쭝) ; KS0-C-4264
(ucs-set-char #xCB64 ?쭤) ; KS0-C-4265
(ucs-set-char #xCB78 ?쭸) ; KS0-C-4266
(ucs-set-char #xCB79 ?쭹) ; KS0-C-4267
(ucs-set-char #xCB9C ?쮜) ; KS0-C-4268
(ucs-set-char #xCBB8 ?쮸) ; KS0-C-4269
(ucs-set-char #xCBD4 ?쯔) ; KS0-C-426A
(ucs-set-char #xCBE4 ?쯤) ; KS0-C-426B
(ucs-set-char #xCBE7 ?쯧) ; KS0-C-426C
(ucs-set-char #xCBE9 ?쯩) ; KS0-C-426D
(ucs-set-char #xCC0C ?찌) ; KS0-C-426E
(ucs-set-char #xCC0D ?찍) ; KS0-C-426F
(ucs-set-char #xCC10 ?찐) ; KS0-C-4270
(ucs-set-char #xCC14 ?찔) ; KS0-C-4271
(ucs-set-char #xCC1C ?찜) ; KS0-C-4272
(ucs-set-char #xCC1D ?찝) ; KS0-C-4273
(ucs-set-char #xCC21 ?찡) ; KS0-C-4274
(ucs-set-char #xCC22 ?찢) ; KS0-C-4275
(ucs-set-char #xCC27 ?찧) ; KS0-C-4276
(ucs-set-char #xCC28 ?차) ; KS0-C-4277
(ucs-set-char #xCC29 ?착) ; KS0-C-4278
(ucs-set-char #xCC2C ?찬) ; KS0-C-4279
(ucs-set-char #xCC2E ?찮) ; KS0-C-427A
(ucs-set-char #xCC30 ?찰) ; KS0-C-427B
(ucs-set-char #xCC38 ?참) ; KS0-C-427C
(ucs-set-char #xCC39 ?찹) ; KS0-C-427D
(ucs-set-char #xCC3B ?찻) ; KS0-C-427E
(ucs-set-char #xCC3C ?찼) ; KS0-C-4321
(ucs-set-char #xCC3D ?창) ; KS0-C-4322
(ucs-set-char #xCC3E ?찾) ; KS0-C-4323
(ucs-set-char #xCC44 ?채) ; KS0-C-4324
(ucs-set-char #xCC45 ?책) ; KS0-C-4325
(ucs-set-char #xCC48 ?챈) ; KS0-C-4326
(ucs-set-char #xCC4C ?챌) ; KS0-C-4327
(ucs-set-char #xCC54 ?챔) ; KS0-C-4328
(ucs-set-char #xCC55 ?챕) ; KS0-C-4329
(ucs-set-char #xCC57 ?챗) ; KS0-C-432A
(ucs-set-char #xCC58 ?챘) ; KS0-C-432B
(ucs-set-char #xCC59 ?챙) ; KS0-C-432C
(ucs-set-char #xCC60 ?챠) ; KS0-C-432D
(ucs-set-char #xCC64 ?챤) ; KS0-C-432E
(ucs-set-char #xCC66 ?챦) ; KS0-C-432F
(ucs-set-char #xCC68 ?챨) ; KS0-C-4330
(ucs-set-char #xCC70 ?챰) ; KS0-C-4331
(ucs-set-char #xCC75 ?챵) ; KS0-C-4332
(ucs-set-char #xCC98 ?처) ; KS0-C-4333
(ucs-set-char #xCC99 ?척) ; KS0-C-4334
(ucs-set-char #xCC9C ?천) ; KS0-C-4335
(ucs-set-char #xCCA0 ?철) ; KS0-C-4336
(ucs-set-char #xCCA8 ?첨) ; KS0-C-4337
(ucs-set-char #xCCA9 ?첩) ; KS0-C-4338
(ucs-set-char #xCCAB ?첫) ; KS0-C-4339
(ucs-set-char #xCCAC ?첬) ; KS0-C-433A
(ucs-set-char #xCCAD ?청) ; KS0-C-433B
(ucs-set-char #xCCB4 ?체) ; KS0-C-433C
(ucs-set-char #xCCB5 ?첵) ; KS0-C-433D
(ucs-set-char #xCCB8 ?첸) ; KS0-C-433E
(ucs-set-char #xCCBC ?첼) ; KS0-C-433F
(ucs-set-char #xCCC4 ?쳄) ; KS0-C-4340
(ucs-set-char #xCCC5 ?쳅) ; KS0-C-4341
(ucs-set-char #xCCC7 ?쳇) ; KS0-C-4342
(ucs-set-char #xCCC9 ?쳉) ; KS0-C-4343
(ucs-set-char #xCCD0 ?쳐) ; KS0-C-4344
(ucs-set-char #xCCD4 ?쳔) ; KS0-C-4345
(ucs-set-char #xCCE4 ?쳤) ; KS0-C-4346
(ucs-set-char #xCCEC ?쳬) ; KS0-C-4347
(ucs-set-char #xCCF0 ?쳰) ; KS0-C-4348
(ucs-set-char #xCD01 ?촁) ; KS0-C-4349
(ucs-set-char #xCD08 ?초) ; KS0-C-434A
(ucs-set-char #xCD09 ?촉) ; KS0-C-434B
(ucs-set-char #xCD0C ?촌) ; KS0-C-434C
(ucs-set-char #xCD10 ?촐) ; KS0-C-434D
(ucs-set-char #xCD18 ?촘) ; KS0-C-434E
(ucs-set-char #xCD19 ?촙) ; KS0-C-434F
(ucs-set-char #xCD1B ?촛) ; KS0-C-4350
(ucs-set-char #xCD1D ?총) ; KS0-C-4351
(ucs-set-char #xCD24 ?촤) ; KS0-C-4352
(ucs-set-char #xCD28 ?촨) ; KS0-C-4353
(ucs-set-char #xCD2C ?촬) ; KS0-C-4354
(ucs-set-char #xCD39 ?촹) ; KS0-C-4355
(ucs-set-char #xCD5C ?최) ; KS0-C-4356
(ucs-set-char #xCD60 ?쵠) ; KS0-C-4357
(ucs-set-char #xCD64 ?쵤) ; KS0-C-4358
(ucs-set-char #xCD6C ?쵬) ; KS0-C-4359
(ucs-set-char #xCD6D ?쵭) ; KS0-C-435A
(ucs-set-char #xCD6F ?쵯) ; KS0-C-435B
(ucs-set-char #xCD71 ?쵱) ; KS0-C-435C
(ucs-set-char #xCD78 ?쵸) ; KS0-C-435D
(ucs-set-char #xCD88 ?춈) ; KS0-C-435E
(ucs-set-char #xCD94 ?추) ; KS0-C-435F
(ucs-set-char #xCD95 ?축) ; KS0-C-4360
(ucs-set-char #xCD98 ?춘) ; KS0-C-4361
(ucs-set-char #xCD9C ?출) ; KS0-C-4362
(ucs-set-char #xCDA4 ?춤) ; KS0-C-4363
(ucs-set-char #xCDA5 ?춥) ; KS0-C-4364
(ucs-set-char #xCDA7 ?춧) ; KS0-C-4365
(ucs-set-char #xCDA9 ?충) ; KS0-C-4366
(ucs-set-char #xCDB0 ?춰) ; KS0-C-4367
(ucs-set-char #xCDC4 ?췄) ; KS0-C-4368
(ucs-set-char #xCDCC ?췌) ; KS0-C-4369
(ucs-set-char #xCDD0 ?췐) ; KS0-C-436A
(ucs-set-char #xCDE8 ?취) ; KS0-C-436B
(ucs-set-char #xCDEC ?췬) ; KS0-C-436C
(ucs-set-char #xCDF0 ?췰) ; KS0-C-436D
(ucs-set-char #xCDF8 ?췸) ; KS0-C-436E
(ucs-set-char #xCDF9 ?췹) ; KS0-C-436F
(ucs-set-char #xCDFB ?췻) ; KS0-C-4370
(ucs-set-char #xCDFD ?췽) ; KS0-C-4371
(ucs-set-char #xCE04 ?츄) ; KS0-C-4372
(ucs-set-char #xCE08 ?츈) ; KS0-C-4373
(ucs-set-char #xCE0C ?츌) ; KS0-C-4374
(ucs-set-char #xCE14 ?츔) ; KS0-C-4375
(ucs-set-char #xCE19 ?츙) ; KS0-C-4376
(ucs-set-char #xCE20 ?츠) ; KS0-C-4377
(ucs-set-char #xCE21 ?측) ; KS0-C-4378
(ucs-set-char #xCE24 ?츤) ; KS0-C-4379
(ucs-set-char #xCE28 ?츨) ; KS0-C-437A
(ucs-set-char #xCE30 ?츰) ; KS0-C-437B
(ucs-set-char #xCE31 ?츱) ; KS0-C-437C
(ucs-set-char #xCE33 ?츳) ; KS0-C-437D
(ucs-set-char #xCE35 ?층) ; KS0-C-437E
(ucs-set-char #xCE58 ?치) ; KS0-C-4421
(ucs-set-char #xCE59 ?칙) ; KS0-C-4422
(ucs-set-char #xCE5C ?친) ; KS0-C-4423
(ucs-set-char #xCE5F ?칟) ; KS0-C-4424
(ucs-set-char #xCE60 ?칠) ; KS0-C-4425
(ucs-set-char #xCE61 ?칡) ; KS0-C-4426
(ucs-set-char #xCE68 ?침) ; KS0-C-4427
(ucs-set-char #xCE69 ?칩) ; KS0-C-4428
(ucs-set-char #xCE6B ?칫) ; KS0-C-4429
(ucs-set-char #xCE6D ?칭) ; KS0-C-442A
(ucs-set-char #xCE74 ?카) ; KS0-C-442B
(ucs-set-char #xCE75 ?칵) ; KS0-C-442C
(ucs-set-char #xCE78 ?칸) ; KS0-C-442D
(ucs-set-char #xCE7C ?칼) ; KS0-C-442E
(ucs-set-char #xCE84 ?캄) ; KS0-C-442F
(ucs-set-char #xCE85 ?캅) ; KS0-C-4430
(ucs-set-char #xCE87 ?캇) ; KS0-C-4431
(ucs-set-char #xCE89 ?캉) ; KS0-C-4432
(ucs-set-char #xCE90 ?캐) ; KS0-C-4433
(ucs-set-char #xCE91 ?캑) ; KS0-C-4434
(ucs-set-char #xCE94 ?캔) ; KS0-C-4435
(ucs-set-char #xCE98 ?캘) ; KS0-C-4436
(ucs-set-char #xCEA0 ?캠) ; KS0-C-4437
(ucs-set-char #xCEA1 ?캡) ; KS0-C-4438
(ucs-set-char #xCEA3 ?캣) ; KS0-C-4439
(ucs-set-char #xCEA4 ?캤) ; KS0-C-443A
(ucs-set-char #xCEA5 ?캥) ; KS0-C-443B
(ucs-set-char #xCEAC ?캬) ; KS0-C-443C
(ucs-set-char #xCEAD ?캭) ; KS0-C-443D
(ucs-set-char #xCEC1 ?컁) ; KS0-C-443E
(ucs-set-char #xCEE4 ?커) ; KS0-C-443F
(ucs-set-char #xCEE5 ?컥) ; KS0-C-4440
(ucs-set-char #xCEE8 ?컨) ; KS0-C-4441
(ucs-set-char #xCEEB ?컫) ; KS0-C-4442
(ucs-set-char #xCEEC ?컬) ; KS0-C-4443
(ucs-set-char #xCEF4 ?컴) ; KS0-C-4444
(ucs-set-char #xCEF5 ?컵) ; KS0-C-4445
(ucs-set-char #xCEF7 ?컷) ; KS0-C-4446
(ucs-set-char #xCEF8 ?컸) ; KS0-C-4447
(ucs-set-char #xCEF9 ?컹) ; KS0-C-4448
(ucs-set-char #xCF00 ?케) ; KS0-C-4449
(ucs-set-char #xCF01 ?켁) ; KS0-C-444A
(ucs-set-char #xCF04 ?켄) ; KS0-C-444B
(ucs-set-char #xCF08 ?켈) ; KS0-C-444C
(ucs-set-char #xCF10 ?켐) ; KS0-C-444D
(ucs-set-char #xCF11 ?켑) ; KS0-C-444E
(ucs-set-char #xCF13 ?켓) ; KS0-C-444F
(ucs-set-char #xCF15 ?켕) ; KS0-C-4450
(ucs-set-char #xCF1C ?켜) ; KS0-C-4451
(ucs-set-char #xCF20 ?켠) ; KS0-C-4452
(ucs-set-char #xCF24 ?켤) ; KS0-C-4453
(ucs-set-char #xCF2C ?켬) ; KS0-C-4454
(ucs-set-char #xCF2D ?켭) ; KS0-C-4455
(ucs-set-char #xCF2F ?켯) ; KS0-C-4456
(ucs-set-char #xCF30 ?켰) ; KS0-C-4457
(ucs-set-char #xCF31 ?켱) ; KS0-C-4458
(ucs-set-char #xCF38 ?켸) ; KS0-C-4459
(ucs-set-char #xCF54 ?코) ; KS0-C-445A
(ucs-set-char #xCF55 ?콕) ; KS0-C-445B
(ucs-set-char #xCF58 ?콘) ; KS0-C-445C
(ucs-set-char #xCF5C ?콜) ; KS0-C-445D
(ucs-set-char #xCF64 ?콤) ; KS0-C-445E
(ucs-set-char #xCF65 ?콥) ; KS0-C-445F
(ucs-set-char #xCF67 ?콧) ; KS0-C-4460
(ucs-set-char #xCF69 ?콩) ; KS0-C-4461
(ucs-set-char #xCF70 ?콰) ; KS0-C-4462
(ucs-set-char #xCF71 ?콱) ; KS0-C-4463
(ucs-set-char #xCF74 ?콴) ; KS0-C-4464
(ucs-set-char #xCF78 ?콸) ; KS0-C-4465
(ucs-set-char #xCF80 ?쾀) ; KS0-C-4466
(ucs-set-char #xCF85 ?쾅) ; KS0-C-4467
(ucs-set-char #xCF8C ?쾌) ; KS0-C-4468
(ucs-set-char #xCFA1 ?쾡) ; KS0-C-4469
(ucs-set-char #xCFA8 ?쾨) ; KS0-C-446A
(ucs-set-char #xCFB0 ?쾰) ; KS0-C-446B
(ucs-set-char #xCFC4 ?쿄) ; KS0-C-446C
(ucs-set-char #xCFE0 ?쿠) ; KS0-C-446D
(ucs-set-char #xCFE1 ?쿡) ; KS0-C-446E
(ucs-set-char #xCFE4 ?쿤) ; KS0-C-446F
(ucs-set-char #xCFE8 ?쿨) ; KS0-C-4470
(ucs-set-char #xCFF0 ?쿰) ; KS0-C-4471
(ucs-set-char #xCFF1 ?쿱) ; KS0-C-4472
(ucs-set-char #xCFF3 ?쿳) ; KS0-C-4473
(ucs-set-char #xCFF5 ?쿵) ; KS0-C-4474
(ucs-set-char #xCFFC ?쿼) ; KS0-C-4475
(ucs-set-char #xD000 ?퀀) ; KS0-C-4476
(ucs-set-char #xD004 ?퀄) ; KS0-C-4477
(ucs-set-char #xD011 ?퀑) ; KS0-C-4478
(ucs-set-char #xD018 ?퀘) ; KS0-C-4479
(ucs-set-char #xD02D ?퀭) ; KS0-C-447A
(ucs-set-char #xD034 ?퀴) ; KS0-C-447B
(ucs-set-char #xD035 ?퀵) ; KS0-C-447C
(ucs-set-char #xD038 ?퀸) ; KS0-C-447D
(ucs-set-char #xD03C ?퀼) ; KS0-C-447E
(ucs-set-char #xD044 ?큄) ; KS0-C-4521
(ucs-set-char #xD045 ?큅) ; KS0-C-4522
(ucs-set-char #xD047 ?큇) ; KS0-C-4523
(ucs-set-char #xD049 ?큉) ; KS0-C-4524
(ucs-set-char #xD050 ?큐) ; KS0-C-4525
(ucs-set-char #xD054 ?큔) ; KS0-C-4526
(ucs-set-char #xD058 ?큘) ; KS0-C-4527
(ucs-set-char #xD060 ?큠) ; KS0-C-4528
(ucs-set-char #xD06C ?크) ; KS0-C-4529
(ucs-set-char #xD06D ?큭) ; KS0-C-452A
(ucs-set-char #xD070 ?큰) ; KS0-C-452B
(ucs-set-char #xD074 ?클) ; KS0-C-452C
(ucs-set-char #xD07C ?큼) ; KS0-C-452D
(ucs-set-char #xD07D ?큽) ; KS0-C-452E
(ucs-set-char #xD081 ?킁) ; KS0-C-452F
(ucs-set-char #xD0A4 ?키) ; KS0-C-4530
(ucs-set-char #xD0A5 ?킥) ; KS0-C-4531
(ucs-set-char #xD0A8 ?킨) ; KS0-C-4532
(ucs-set-char #xD0AC ?킬) ; KS0-C-4533
(ucs-set-char #xD0B4 ?킴) ; KS0-C-4534
(ucs-set-char #xD0B5 ?킵) ; KS0-C-4535
(ucs-set-char #xD0B7 ?킷) ; KS0-C-4536
(ucs-set-char #xD0B9 ?킹) ; KS0-C-4537
(ucs-set-char #xD0C0 ?타) ; KS0-C-4538
(ucs-set-char #xD0C1 ?탁) ; KS0-C-4539
(ucs-set-char #xD0C4 ?탄) ; KS0-C-453A
(ucs-set-char #xD0C8 ?탈) ; KS0-C-453B
(ucs-set-char #xD0C9 ?탉) ; KS0-C-453C
(ucs-set-char #xD0D0 ?탐) ; KS0-C-453D
(ucs-set-char #xD0D1 ?탑) ; KS0-C-453E
(ucs-set-char #xD0D3 ?탓) ; KS0-C-453F
(ucs-set-char #xD0D4 ?탔) ; KS0-C-4540
(ucs-set-char #xD0D5 ?탕) ; KS0-C-4541
(ucs-set-char #xD0DC ?태) ; KS0-C-4542
(ucs-set-char #xD0DD ?택) ; KS0-C-4543
(ucs-set-char #xD0E0 ?탠) ; KS0-C-4544
(ucs-set-char #xD0E4 ?탤) ; KS0-C-4545
(ucs-set-char #xD0EC ?탬) ; KS0-C-4546
(ucs-set-char #xD0ED ?탭) ; KS0-C-4547
(ucs-set-char #xD0EF ?탯) ; KS0-C-4548
(ucs-set-char #xD0F0 ?탰) ; KS0-C-4549
(ucs-set-char #xD0F1 ?탱) ; KS0-C-454A
(ucs-set-char #xD0F8 ?탸) ; KS0-C-454B
(ucs-set-char #xD10D ?턍) ; KS0-C-454C
(ucs-set-char #xD130 ?터) ; KS0-C-454D
(ucs-set-char #xD131 ?턱) ; KS0-C-454E
(ucs-set-char #xD134 ?턴) ; KS0-C-454F
(ucs-set-char #xD138 ?털) ; KS0-C-4550
(ucs-set-char #xD13A ?턺) ; KS0-C-4551
(ucs-set-char #xD140 ?텀) ; KS0-C-4552
(ucs-set-char #xD141 ?텁) ; KS0-C-4553
(ucs-set-char #xD143 ?텃) ; KS0-C-4554
(ucs-set-char #xD144 ?텄) ; KS0-C-4555
(ucs-set-char #xD145 ?텅) ; KS0-C-4556
(ucs-set-char #xD14C ?테) ; KS0-C-4557
(ucs-set-char #xD14D ?텍) ; KS0-C-4558
(ucs-set-char #xD150 ?텐) ; KS0-C-4559
(ucs-set-char #xD154 ?텔) ; KS0-C-455A
(ucs-set-char #xD15C ?템) ; KS0-C-455B
(ucs-set-char #xD15D ?텝) ; KS0-C-455C
(ucs-set-char #xD15F ?텟) ; KS0-C-455D
(ucs-set-char #xD161 ?텡) ; KS0-C-455E
(ucs-set-char #xD168 ?텨) ; KS0-C-455F
(ucs-set-char #xD16C ?텬) ; KS0-C-4560
(ucs-set-char #xD17C ?텼) ; KS0-C-4561
(ucs-set-char #xD184 ?톄) ; KS0-C-4562
(ucs-set-char #xD188 ?톈) ; KS0-C-4563
(ucs-set-char #xD1A0 ?토) ; KS0-C-4564
(ucs-set-char #xD1A1 ?톡) ; KS0-C-4565
(ucs-set-char #xD1A4 ?톤) ; KS0-C-4566
(ucs-set-char #xD1A8 ?톨) ; KS0-C-4567
(ucs-set-char #xD1B0 ?톰) ; KS0-C-4568
(ucs-set-char #xD1B1 ?톱) ; KS0-C-4569
(ucs-set-char #xD1B3 ?톳) ; KS0-C-456A
(ucs-set-char #xD1B5 ?통) ; KS0-C-456B
(ucs-set-char #xD1BA ?톺) ; KS0-C-456C
(ucs-set-char #xD1BC ?톼) ; KS0-C-456D
(ucs-set-char #xD1C0 ?퇀) ; KS0-C-456E
(ucs-set-char #xD1D8 ?퇘) ; KS0-C-456F
(ucs-set-char #xD1F4 ?퇴) ; KS0-C-4570
(ucs-set-char #xD1F8 ?퇸) ; KS0-C-4571
(ucs-set-char #xD207 ?툇) ; KS0-C-4572
(ucs-set-char #xD209 ?툉) ; KS0-C-4573
(ucs-set-char #xD210 ?툐) ; KS0-C-4574
(ucs-set-char #xD22C ?투) ; KS0-C-4575
(ucs-set-char #xD22D ?툭) ; KS0-C-4576
(ucs-set-char #xD230 ?툰) ; KS0-C-4577
(ucs-set-char #xD234 ?툴) ; KS0-C-4578
(ucs-set-char #xD23C ?툼) ; KS0-C-4579
(ucs-set-char #xD23D ?툽) ; KS0-C-457A
(ucs-set-char #xD23F ?툿) ; KS0-C-457B
(ucs-set-char #xD241 ?퉁) ; KS0-C-457C
(ucs-set-char #xD248 ?퉈) ; KS0-C-457D
(ucs-set-char #xD25C ?퉜) ; KS0-C-457E
(ucs-set-char #xD264 ?퉤) ; KS0-C-4621
(ucs-set-char #xD280 ?튀) ; KS0-C-4622
(ucs-set-char #xD281 ?튁) ; KS0-C-4623
(ucs-set-char #xD284 ?튄) ; KS0-C-4624
(ucs-set-char #xD288 ?튈) ; KS0-C-4625
(ucs-set-char #xD290 ?튐) ; KS0-C-4626
(ucs-set-char #xD291 ?튑) ; KS0-C-4627
(ucs-set-char #xD295 ?튕) ; KS0-C-4628
(ucs-set-char #xD29C ?튜) ; KS0-C-4629
(ucs-set-char #xD2A0 ?튠) ; KS0-C-462A
(ucs-set-char #xD2A4 ?튤) ; KS0-C-462B
(ucs-set-char #xD2AC ?튬) ; KS0-C-462C
(ucs-set-char #xD2B1 ?튱) ; KS0-C-462D
(ucs-set-char #xD2B8 ?트) ; KS0-C-462E
(ucs-set-char #xD2B9 ?특) ; KS0-C-462F
(ucs-set-char #xD2BC ?튼) ; KS0-C-4630
(ucs-set-char #xD2BF ?튿) ; KS0-C-4631
(ucs-set-char #xD2C0 ?틀) ; KS0-C-4632
(ucs-set-char #xD2C2 ?틂) ; KS0-C-4633
(ucs-set-char #xD2C8 ?틈) ; KS0-C-4634
(ucs-set-char #xD2C9 ?틉) ; KS0-C-4635
(ucs-set-char #xD2CB ?틋) ; KS0-C-4636
(ucs-set-char #xD2D4 ?틔) ; KS0-C-4637
(ucs-set-char #xD2D8 ?틘) ; KS0-C-4638
(ucs-set-char #xD2DC ?틜) ; KS0-C-4639
(ucs-set-char #xD2E4 ?틤) ; KS0-C-463A
(ucs-set-char #xD2E5 ?틥) ; KS0-C-463B
(ucs-set-char #xD2F0 ?티) ; KS0-C-463C
(ucs-set-char #xD2F1 ?틱) ; KS0-C-463D
(ucs-set-char #xD2F4 ?틴) ; KS0-C-463E
(ucs-set-char #xD2F8 ?틸) ; KS0-C-463F
(ucs-set-char #xD300 ?팀) ; KS0-C-4640
(ucs-set-char #xD301 ?팁) ; KS0-C-4641
(ucs-set-char #xD303 ?팃) ; KS0-C-4642
(ucs-set-char #xD305 ?팅) ; KS0-C-4643
(ucs-set-char #xD30C ?파) ; KS0-C-4644
(ucs-set-char #xD30D ?팍) ; KS0-C-4645
(ucs-set-char #xD30E ?팎) ; KS0-C-4646
(ucs-set-char #xD310 ?판) ; KS0-C-4647
(ucs-set-char #xD314 ?팔) ; KS0-C-4648
(ucs-set-char #xD316 ?팖) ; KS0-C-4649
(ucs-set-char #xD31C ?팜) ; KS0-C-464A
(ucs-set-char #xD31D ?팝) ; KS0-C-464B
(ucs-set-char #xD31F ?팟) ; KS0-C-464C
(ucs-set-char #xD320 ?팠) ; KS0-C-464D
(ucs-set-char #xD321 ?팡) ; KS0-C-464E
(ucs-set-char #xD325 ?팥) ; KS0-C-464F
(ucs-set-char #xD328 ?패) ; KS0-C-4650
(ucs-set-char #xD329 ?팩) ; KS0-C-4651
(ucs-set-char #xD32C ?팬) ; KS0-C-4652
(ucs-set-char #xD330 ?팰) ; KS0-C-4653
(ucs-set-char #xD338 ?팸) ; KS0-C-4654
(ucs-set-char #xD339 ?팹) ; KS0-C-4655
(ucs-set-char #xD33B ?팻) ; KS0-C-4656
(ucs-set-char #xD33C ?팼) ; KS0-C-4657
(ucs-set-char #xD33D ?팽) ; KS0-C-4658
(ucs-set-char #xD344 ?퍄) ; KS0-C-4659
(ucs-set-char #xD345 ?퍅) ; KS0-C-465A
(ucs-set-char #xD37C ?퍼) ; KS0-C-465B
(ucs-set-char #xD37D ?퍽) ; KS0-C-465C
(ucs-set-char #xD380 ?펀) ; KS0-C-465D
(ucs-set-char #xD384 ?펄) ; KS0-C-465E
(ucs-set-char #xD38C ?펌) ; KS0-C-465F
(ucs-set-char #xD38D ?펍) ; KS0-C-4660
(ucs-set-char #xD38F ?펏) ; KS0-C-4661
(ucs-set-char #xD390 ?펐) ; KS0-C-4662
(ucs-set-char #xD391 ?펑) ; KS0-C-4663
(ucs-set-char #xD398 ?페) ; KS0-C-4664
(ucs-set-char #xD399 ?펙) ; KS0-C-4665
(ucs-set-char #xD39C ?펜) ; KS0-C-4666
(ucs-set-char #xD3A0 ?펠) ; KS0-C-4667
(ucs-set-char #xD3A8 ?펨) ; KS0-C-4668
(ucs-set-char #xD3A9 ?펩) ; KS0-C-4669
(ucs-set-char #xD3AB ?펫) ; KS0-C-466A
(ucs-set-char #xD3AD ?펭) ; KS0-C-466B
(ucs-set-char #xD3B4 ?펴) ; KS0-C-466C
(ucs-set-char #xD3B8 ?편) ; KS0-C-466D
(ucs-set-char #xD3BC ?펼) ; KS0-C-466E
(ucs-set-char #xD3C4 ?폄) ; KS0-C-466F
(ucs-set-char #xD3C5 ?폅) ; KS0-C-4670
(ucs-set-char #xD3C8 ?폈) ; KS0-C-4671
(ucs-set-char #xD3C9 ?평) ; KS0-C-4672
(ucs-set-char #xD3D0 ?폐) ; KS0-C-4673
(ucs-set-char #xD3D8 ?폘) ; KS0-C-4674
(ucs-set-char #xD3E1 ?폡) ; KS0-C-4675
(ucs-set-char #xD3E3 ?폣) ; KS0-C-4676
(ucs-set-char #xD3EC ?포) ; KS0-C-4677
(ucs-set-char #xD3ED ?폭) ; KS0-C-4678
(ucs-set-char #xD3F0 ?폰) ; KS0-C-4679
(ucs-set-char #xD3F4 ?폴) ; KS0-C-467A
(ucs-set-char #xD3FC ?폼) ; KS0-C-467B
(ucs-set-char #xD3FD ?폽) ; KS0-C-467C
(ucs-set-char #xD3FF ?폿) ; KS0-C-467D
(ucs-set-char #xD401 ?퐁) ; KS0-C-467E
(ucs-set-char #xD408 ?퐈) ; KS0-C-4721
(ucs-set-char #xD41D ?퐝) ; KS0-C-4722
(ucs-set-char #xD440 ?푀) ; KS0-C-4723
(ucs-set-char #xD444 ?푄) ; KS0-C-4724
(ucs-set-char #xD45C ?표) ; KS0-C-4725
(ucs-set-char #xD460 ?푠) ; KS0-C-4726
(ucs-set-char #xD464 ?푤) ; KS0-C-4727
(ucs-set-char #xD46D ?푭) ; KS0-C-4728
(ucs-set-char #xD46F ?푯) ; KS0-C-4729
(ucs-set-char #xD478 ?푸) ; KS0-C-472A
(ucs-set-char #xD479 ?푹) ; KS0-C-472B
(ucs-set-char #xD47C ?푼) ; KS0-C-472C
(ucs-set-char #xD47F ?푿) ; KS0-C-472D
(ucs-set-char #xD480 ?풀) ; KS0-C-472E
(ucs-set-char #xD482 ?풂) ; KS0-C-472F
(ucs-set-char #xD488 ?품) ; KS0-C-4730
(ucs-set-char #xD489 ?풉) ; KS0-C-4731
(ucs-set-char #xD48B ?풋) ; KS0-C-4732
(ucs-set-char #xD48D ?풍) ; KS0-C-4733
(ucs-set-char #xD494 ?풔) ; KS0-C-4734
(ucs-set-char #xD4A9 ?풩) ; KS0-C-4735
(ucs-set-char #xD4CC ?퓌) ; KS0-C-4736
(ucs-set-char #xD4D0 ?퓐) ; KS0-C-4737
(ucs-set-char #xD4D4 ?퓔) ; KS0-C-4738
(ucs-set-char #xD4DC ?퓜) ; KS0-C-4739
(ucs-set-char #xD4DF ?퓟) ; KS0-C-473A
(ucs-set-char #xD4E8 ?퓨) ; KS0-C-473B
(ucs-set-char #xD4EC ?퓬) ; KS0-C-473C
(ucs-set-char #xD4F0 ?퓰) ; KS0-C-473D
(ucs-set-char #xD4F8 ?퓸) ; KS0-C-473E
(ucs-set-char #xD4FB ?퓻) ; KS0-C-473F
(ucs-set-char #xD4FD ?퓽) ; KS0-C-4740
(ucs-set-char #xD504 ?프) ; KS0-C-4741
(ucs-set-char #xD508 ?픈) ; KS0-C-4742
(ucs-set-char #xD50C ?플) ; KS0-C-4743
(ucs-set-char #xD514 ?픔) ; KS0-C-4744
(ucs-set-char #xD515 ?픕) ; KS0-C-4745
(ucs-set-char #xD517 ?픗) ; KS0-C-4746
(ucs-set-char #xD53C ?피) ; KS0-C-4747
(ucs-set-char #xD53D ?픽) ; KS0-C-4748
(ucs-set-char #xD540 ?핀) ; KS0-C-4749
(ucs-set-char #xD544 ?필) ; KS0-C-474A
(ucs-set-char #xD54C ?핌) ; KS0-C-474B
(ucs-set-char #xD54D ?핍) ; KS0-C-474C
(ucs-set-char #xD54F ?핏) ; KS0-C-474D
(ucs-set-char #xD551 ?핑) ; KS0-C-474E
(ucs-set-char #xD558 ?하) ; KS0-C-474F
(ucs-set-char #xD559 ?학) ; KS0-C-4750
(ucs-set-char #xD55C ?한) ; KS0-C-4751
(ucs-set-char #xD560 ?할) ; KS0-C-4752
(ucs-set-char #xD565 ?핥) ; KS0-C-4753
(ucs-set-char #xD568 ?함) ; KS0-C-4754
(ucs-set-char #xD569 ?합) ; KS0-C-4755
(ucs-set-char #xD56B ?핫) ; KS0-C-4756
(ucs-set-char #xD56D ?항) ; KS0-C-4757
(ucs-set-char #xD574 ?해) ; KS0-C-4758
(ucs-set-char #xD575 ?핵) ; KS0-C-4759
(ucs-set-char #xD578 ?핸) ; KS0-C-475A
(ucs-set-char #xD57C ?핼) ; KS0-C-475B
(ucs-set-char #xD584 ?햄) ; KS0-C-475C
(ucs-set-char #xD585 ?햅) ; KS0-C-475D
(ucs-set-char #xD587 ?햇) ; KS0-C-475E
(ucs-set-char #xD588 ?했) ; KS0-C-475F
(ucs-set-char #xD589 ?행) ; KS0-C-4760
(ucs-set-char #xD590 ?햐) ; KS0-C-4761
(ucs-set-char #xD5A5 ?향) ; KS0-C-4762
(ucs-set-char #xD5C8 ?허) ; KS0-C-4763
(ucs-set-char #xD5C9 ?헉) ; KS0-C-4764
(ucs-set-char #xD5CC ?헌) ; KS0-C-4765
(ucs-set-char #xD5D0 ?헐) ; KS0-C-4766
(ucs-set-char #xD5D2 ?헒) ; KS0-C-4767
(ucs-set-char #xD5D8 ?험) ; KS0-C-4768
(ucs-set-char #xD5D9 ?헙) ; KS0-C-4769
(ucs-set-char #xD5DB ?헛) ; KS0-C-476A
(ucs-set-char #xD5DD ?헝) ; KS0-C-476B
(ucs-set-char #xD5E4 ?헤) ; KS0-C-476C
(ucs-set-char #xD5E5 ?헥) ; KS0-C-476D
(ucs-set-char #xD5E8 ?헨) ; KS0-C-476E
(ucs-set-char #xD5EC ?헬) ; KS0-C-476F
(ucs-set-char #xD5F4 ?헴) ; KS0-C-4770
(ucs-set-char #xD5F5 ?헵) ; KS0-C-4771
(ucs-set-char #xD5F7 ?헷) ; KS0-C-4772
(ucs-set-char #xD5F9 ?헹) ; KS0-C-4773
(ucs-set-char #xD600 ?혀) ; KS0-C-4774
(ucs-set-char #xD601 ?혁) ; KS0-C-4775
(ucs-set-char #xD604 ?현) ; KS0-C-4776
(ucs-set-char #xD608 ?혈) ; KS0-C-4777
(ucs-set-char #xD610 ?혐) ; KS0-C-4778
(ucs-set-char #xD611 ?협) ; KS0-C-4779
(ucs-set-char #xD613 ?혓) ; KS0-C-477A
(ucs-set-char #xD614 ?혔) ; KS0-C-477B
(ucs-set-char #xD615 ?형) ; KS0-C-477C
(ucs-set-char #xD61C ?혜) ; KS0-C-477D
(ucs-set-char #xD620 ?혠) ; KS0-C-477E
(ucs-set-char #xD624 ?혤) ; KS0-C-4821
(ucs-set-char #xD62D ?혭) ; KS0-C-4822
(ucs-set-char #xD638 ?호) ; KS0-C-4823
(ucs-set-char #xD639 ?혹) ; KS0-C-4824
(ucs-set-char #xD63C ?혼) ; KS0-C-4825
(ucs-set-char #xD640 ?홀) ; KS0-C-4826
(ucs-set-char #xD645 ?홅) ; KS0-C-4827
(ucs-set-char #xD648 ?홈) ; KS0-C-4828
(ucs-set-char #xD649 ?홉) ; KS0-C-4829
(ucs-set-char #xD64B ?홋) ; KS0-C-482A
(ucs-set-char #xD64D ?홍) ; KS0-C-482B
(ucs-set-char #xD651 ?홑) ; KS0-C-482C
(ucs-set-char #xD654 ?화) ; KS0-C-482D
(ucs-set-char #xD655 ?확) ; KS0-C-482E
(ucs-set-char #xD658 ?환) ; KS0-C-482F
(ucs-set-char #xD65C ?활) ; KS0-C-4830
(ucs-set-char #xD667 ?홧) ; KS0-C-4831
(ucs-set-char #xD669 ?황) ; KS0-C-4832
(ucs-set-char #xD670 ?홰) ; KS0-C-4833
(ucs-set-char #xD671 ?홱) ; KS0-C-4834
(ucs-set-char #xD674 ?홴) ; KS0-C-4835
(ucs-set-char #xD683 ?횃) ; KS0-C-4836
(ucs-set-char #xD685 ?횅) ; KS0-C-4837
(ucs-set-char #xD68C ?회) ; KS0-C-4838
(ucs-set-char #xD68D ?획) ; KS0-C-4839
(ucs-set-char #xD690 ?횐) ; KS0-C-483A
(ucs-set-char #xD694 ?횔) ; KS0-C-483B
(ucs-set-char #xD69D ?횝) ; KS0-C-483C
(ucs-set-char #xD69F ?횟) ; KS0-C-483D
(ucs-set-char #xD6A1 ?횡) ; KS0-C-483E
(ucs-set-char #xD6A8 ?효) ; KS0-C-483F
(ucs-set-char #xD6AC ?횬) ; KS0-C-4840
(ucs-set-char #xD6B0 ?횰) ; KS0-C-4841
(ucs-set-char #xD6B9 ?횹) ; KS0-C-4842
(ucs-set-char #xD6BB ?횻) ; KS0-C-4843
(ucs-set-char #xD6C4 ?후) ; KS0-C-4844
(ucs-set-char #xD6C5 ?훅) ; KS0-C-4845
(ucs-set-char #xD6C8 ?훈) ; KS0-C-4846
(ucs-set-char #xD6CC ?훌) ; KS0-C-4847
(ucs-set-char #xD6D1 ?훑) ; KS0-C-4848
(ucs-set-char #xD6D4 ?훔) ; KS0-C-4849
(ucs-set-char #xD6D7 ?훗) ; KS0-C-484A
(ucs-set-char #xD6D9 ?훙) ; KS0-C-484B
(ucs-set-char #xD6E0 ?훠) ; KS0-C-484C
(ucs-set-char #xD6E4 ?훤) ; KS0-C-484D
(ucs-set-char #xD6E8 ?훨) ; KS0-C-484E
(ucs-set-char #xD6F0 ?훰) ; KS0-C-484F
(ucs-set-char #xD6F5 ?훵) ; KS0-C-4850
(ucs-set-char #xD6FC ?훼) ; KS0-C-4851
(ucs-set-char #xD6FD ?훽) ; KS0-C-4852
(ucs-set-char #xD700 ?휀) ; KS0-C-4853
(ucs-set-char #xD704 ?휄) ; KS0-C-4854
(ucs-set-char #xD711 ?휑) ; KS0-C-4855
(ucs-set-char #xD718 ?휘) ; KS0-C-4856
(ucs-set-char #xD719 ?휙) ; KS0-C-4857
(ucs-set-char #xD71C ?휜) ; KS0-C-4858
(ucs-set-char #xD720 ?휠) ; KS0-C-4859
(ucs-set-char #xD728 ?휨) ; KS0-C-485A
(ucs-set-char #xD729 ?휩) ; KS0-C-485B
(ucs-set-char #xD72B ?휫) ; KS0-C-485C
(ucs-set-char #xD72D ?휭) ; KS0-C-485D
(ucs-set-char #xD734 ?휴) ; KS0-C-485E
(ucs-set-char #xD735 ?휵) ; KS0-C-485F
(ucs-set-char #xD738 ?휸) ; KS0-C-4860
(ucs-set-char #xD73C ?휼) ; KS0-C-4861
(ucs-set-char #xD744 ?흄) ; KS0-C-4862
(ucs-set-char #xD747 ?흇) ; KS0-C-4863
(ucs-set-char #xD749 ?흉) ; KS0-C-4864
(ucs-set-char #xD750 ?흐) ; KS0-C-4865
(ucs-set-char #xD751 ?흑) ; KS0-C-4866
(ucs-set-char #xD754 ?흔) ; KS0-C-4867
(ucs-set-char #xD756 ?흖) ; KS0-C-4868
(ucs-set-char #xD757 ?흗) ; KS0-C-4869
(ucs-set-char #xD758 ?흘) ; KS0-C-486A
(ucs-set-char #xD759 ?흙) ; KS0-C-486B
(ucs-set-char #xD760 ?흠) ; KS0-C-486C
(ucs-set-char #xD761 ?흡) ; KS0-C-486D
(ucs-set-char #xD763 ?흣) ; KS0-C-486E
(ucs-set-char #xD765 ?흥) ; KS0-C-486F
(ucs-set-char #xD769 ?흩) ; KS0-C-4870
(ucs-set-char #xD76C ?희) ; KS0-C-4871
(ucs-set-char #xD770 ?흰) ; KS0-C-4872
(ucs-set-char #xD774 ?흴) ; KS0-C-4873
(ucs-set-char #xD77C ?흼) ; KS0-C-4874
(ucs-set-char #xD77D ?흽) ; KS0-C-4875
(ucs-set-char #xD781 ?힁) ; KS0-C-4876
(ucs-set-char #xD788 ?히) ; KS0-C-4877
(ucs-set-char #xD789 ?힉) ; KS0-C-4878
(ucs-set-char #xD78C ?힌) ; KS0-C-4879
(ucs-set-char #xD790 ?힐) ; KS0-C-487A
(ucs-set-char #xD798 ?힘) ; KS0-C-487B
(ucs-set-char #xD799 ?힙) ; KS0-C-487C
(ucs-set-char #xD79B ?힛) ; KS0-C-487D
(ucs-set-char #xD79D ?힝) ; KS0-C-487E

;;; ucs-hangul.el ends here
